@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2019 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -86,7 +88,8 @@ public class CopyDataCommandHandlerTest {
             }
 
             @Override
-            public void setDataValue(int columnIndex, int rowIndex, Object newValue) {}
+            public void setDataValue(int columnIndex, int rowIndex, Object newValue) {
+            }
 
         };
     }
@@ -110,7 +113,8 @@ public class CopyDataCommandHandlerTest {
             }
 
             @Override
-            public void setDataValue(int columnIndex, int rowIndex, Object newValue) {}
+            public void setDataValue(int columnIndex, int rowIndex, Object newValue) {
+            }
         };
     }
 
