@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2018 Dirk Fauth.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2017, 2020 Dirk Fauth.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -17,7 +19,6 @@ import static org.junit.Assert.assertTrue;
 
 import java.io.Serializable;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.Date;
 import java.util.List;
 
@@ -570,13 +571,7 @@ public class DataChangeLayerIdIndexTest {
         assertEquals("Zoolander", this.dataLayer.getDataValue(1, 2));
 
         // sort
-        Collections.sort(this.dataModel, new Comparator<Person>() {
-
-            @Override
-            public int compare(Person o1, Person o2) {
-                return o1.getLastName().compareTo(o2.getLastName());
-            }
-        });
+        Collections.sort(this.dataModel, (o1, o2) -> o1.getLastName().compareTo(o2.getLastName()));
         // fire event to trigger update of cached row indexes
         this.dataLayer.fireLayerEvent(new RowStructuralRefreshEvent(this.dataLayer));
 
@@ -649,13 +644,7 @@ public class DataChangeLayerIdIndexTest {
         // NOTE: this is because we are storing the data temporary and therefore
         // sorting for lastname would not respect the shown data.
         this.dataLayer.setDataValueByPosition(0, 2, "Yosefine");
-        Collections.sort(this.dataModel, new Comparator<Person>() {
-
-            @Override
-            public int compare(Person o1, Person o2) {
-                return o1.getFirstName().compareTo(o2.getFirstName());
-            }
-        });
+        Collections.sort(this.dataModel, (o1, o2) -> o1.getFirstName().compareTo(o2.getFirstName()));
         // fire event to trigger update of cached row indexes
         this.dataLayer.fireLayerEvent(new RowStructuralRefreshEvent(this.dataLayer));
 
