@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2018 Dirk Fauth.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2018, 2020 Dirk Fauth.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -365,7 +367,7 @@ public class RowStructuralDataChangeIdIndexTest {
         assertEquals(1, this.dataChangeLayer.dataChanges.size());
         assertEquals(1, this.deleteHandler.dataChanges.size());
 
-        RowDeleteDataChange change = this.deleteHandler.dataChanges.get(10);
+        RowDeleteDataChange change = this.deleteHandler.dataChanges.get(Integer.valueOf(10));
         assertNotNull(change);
         assertEquals(10, change.getKey());
         assertEquals(toDelete, change.getValue());
@@ -389,7 +391,7 @@ public class RowStructuralDataChangeIdIndexTest {
         assertFalse("Cell 0/10 is dirty", this.dataChangeLayer.isCellDirty(0, 10));
         assertFalse("Dirty label set", this.dataChangeLayer.getConfigLabelsByPosition(1, 10).hasLabel(DataChangeLayer.DIRTY));
 
-        RowDeleteDataChange change = this.deleteHandler.dataChanges.get(10);
+        RowDeleteDataChange change = this.deleteHandler.dataChanges.get(Integer.valueOf(10));
         assertNotNull(change);
         assertEquals(10, change.getKey());
         assertEquals(toDelete, change.getValue());
