@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -19,9 +21,15 @@ import java.util.Collection;
 import java.util.List;
 
 import org.eclipse.nebula.widgets.nattable.coordinate.Range;
+import org.eclipse.nebula.widgets.nattable.data.ISpanningDataProvider;
+import org.eclipse.nebula.widgets.nattable.data.WrappingSpanningDataProvider;
 import org.eclipse.nebula.widgets.nattable.hideshow.event.ShowColumnPositionsEvent;
 import org.eclipse.nebula.widgets.nattable.hideshow.indicator.HideIndicatorConstants;
 import org.eclipse.nebula.widgets.nattable.layer.LabelStack;
+import org.eclipse.nebula.widgets.nattable.layer.SpanningDataLayer;
+import org.eclipse.nebula.widgets.nattable.layer.cell.DataCell;
+import org.eclipse.nebula.widgets.nattable.layer.cell.ILayerCell;
+import org.eclipse.nebula.widgets.nattable.test.fixture.data.DataProviderFixture;
 import org.eclipse.nebula.widgets.nattable.test.fixture.layer.ColumnHideShowLayerFixture;
 import org.eclipse.nebula.widgets.nattable.test.fixture.layer.DataLayerFixture;
 import org.eclipse.nebula.widgets.nattable.test.fixture.layer.LayerListenerFixture;
@@ -69,17 +77,16 @@ public class ColumnHideShowLayerTest {
 
     @Test
     public void hideAllColumns() {
-        this.columnHideShowLayer.hideColumnPositions(Arrays.asList(0, 1, 2));
+        this.columnHideShowLayer.hideColumnPositions(0, 1, 2);
 
         assertEquals(0, this.columnHideShowLayer.getColumnCount());
     }
 
     @Test
     public void hideAllColumns2() {
-        List<Integer> columnPositions = Arrays.asList(0);
-        this.columnHideShowLayer.hideColumnPositions(columnPositions);
-        this.columnHideShowLayer.hideColumnPositions(columnPositions);
-        this.columnHideShowLayer.hideColumnPositions(columnPositions);
+        this.columnHideShowLayer.hideColumnPositions(0);
+        this.columnHideShowLayer.hideColumnPositions(0);
+        this.columnHideShowLayer.hideColumnPositions(0);
         assertEquals(0, this.columnHideShowLayer.getColumnCount());
     }
 
@@ -151,6 +158,25 @@ public class ColumnHideShowLayerTest {
         assertEquals(4, this.columnHideShowLayer.getColumnPositionByIndex(4));
     }
 
+    @Test
+    public void showColumnIndexesPrimitive() {
+        this.columnHideShowLayer = new ColumnHideShowLayerFixture(
+                new DataLayerFixture(10, 10, 100, 20));
+
+        assertEquals(10, this.columnHideShowLayer.getColumnCount());
+
+        this.columnHideShowLayer.hideColumnPositions(3, 4, 5);
+        assertEquals(7, this.columnHideShowLayer.getColumnCount());
+        assertEquals(-1, this.columnHideShowLayer.getColumnPositionByIndex(3));
+        assertEquals(-1, this.columnHideShowLayer.getColumnPositionByIndex(4));
+
+        this.columnHideShowLayer.showColumnIndexes(3, 4);
+        assertEquals(9, this.columnHideShowLayer.getColumnCount());
+        assertEquals(3, this.columnHideShowLayer.getColumnPositionByIndex(3));
+        assertEquals(4, this.columnHideShowLayer.getColumnPositionByIndex(4));
+
+    }
+
     @Test
     public void showColumnPositions() {
         // Column reorder fixture index positions: 4 1 0 2 3
@@ -342,4 +368,84 @@ public class ColumnHideShowLayerTest {
         assertEquals(0, this.columnHideShowLayer.getWidth());
     }
 
+    @Test
+    public void shouldTransformLocalToUnderlyingColumnPositionHidden() {
+        assertEquals(-1, this.columnHideShowLayer.localToUnderlyingColumnPosition(-1));
+        assertEquals(0, this.columnHideShowLayer.localToUnderlyingColumnPosition(0));
+        assertEquals(1, this.columnHideShowLayer.localToUnderlyingColumnPosition(1));
+        assertEquals(3, this.columnHideShowLayer.localToUnderlyingColumnPosition(2));
+        assertEquals(-1, this.columnHideShowLayer.localToUnderlyingColumnPosition(3));
+    }
+
+    @Test
+    public void shouldTransformLocalToUnderlyingColumnPositionNothingHidden() {
+        this.columnHideShowLayer.showAllColumns();
+
+        assertEquals(-1, this.columnHideShowLayer.localToUnderlyingColumnPosition(-1));
+        assertEquals(0, this.columnHideShowLayer.localToUnderlyingColumnPosition(0));
+        assertEquals(1, this.columnHideShowLayer.localToUnderlyingColumnPosition(1));
+        assertEquals(2, this.columnHideShowLayer.localToUnderlyingColumnPosition(2));
+        assertEquals(3, this.columnHideShowLayer.localToUnderlyingColumnPosition(3));
+        assertEquals(4, this.columnHideShowLayer.localToUnderlyingColumnPosition(4));
+        assertEquals(-1, this.columnHideShowLayer.localToUnderlyingColumnPosition(5));
+    }
+
+    @Test
+    public void shouldReturnHiddenColumnIndexes() {
+        // test initialization hides column indexes 0 and 3
+        // happens due to reordering and hiding
+
+        Collection<Integer> hiddenColumnIndexes = this.columnHideShowLayer.getHiddenColumnIndexes();
+        assertEquals(2, hiddenColumnIndexes.size());
+        assertTrue(hiddenColumnIndexes.contains(Integer.valueOf(0)));
+        assertTrue(hiddenColumnIndexes.contains(Integer.valueOf(3)));
+
+        int[] hiddenColumnIndexesArray = this.columnHideShowLayer.getHiddenColumnIndexesArray();
+        assertEquals(2, hiddenColumnIndexesArray.length);
+        assertEquals(0, hiddenColumnIndexesArray[0]);
+        assertEquals(3, hiddenColumnIndexesArray[1]);
+
+        assertTrue(this.columnHideShowLayer.hasHiddenColumns());
+
+        this.columnHideShowLayer.showAllColumns();
+
+        hiddenColumnIndexes = this.columnHideShowLayer.getHiddenColumnIndexes();
+        assertEquals(0, hiddenColumnIndexes.size());
+
+        hiddenColumnIndexesArray = this.columnHideShowLayer.getHiddenColumnIndexesArray();
+        assertEquals(0, hiddenColumnIndexesArray.length);
+
+        assertFalse(this.columnHideShowLayer.hasHiddenColumns());
+    }
+
+    @Test
+    public void shouldHandleHiddenColumnsInSpanning() {
+        ISpanningDataProvider dataProvider = new WrappingSpanningDataProvider(new DataProviderFixture(5, 5)) {
+
+            @Override
+            public DataCell getCellByPosition(int columnPosition, int rowPosition) {
+                if (columnPosition == 0) {
+                    return new DataCell(columnPosition, rowPosition);
+                }
+                // span column 1 to 4
+                return new DataCell(1, rowPosition, getColumnCount() - 1, 1);
+            }
+
+        };
+
+        this.columnHideShowLayer = new ColumnHideShowLayer(new SpanningDataLayer(dataProvider));
+
+        // test spanned cell
+        ILayerCell cell = this.columnHideShowLayer.getCellByPosition(1, 1);
+        assertEquals(1, cell.getOriginColumnPosition());
+        assertEquals(4, cell.getColumnSpan());
+
+        // hide column
+        this.columnHideShowLayer.hideColumnPositions(3);
+
+        // test spanning decreased
+        cell = this.columnHideShowLayer.getCellByPosition(1, 1);
+        assertEquals(1, cell.getOriginColumnPosition());
+        assertEquals(3, cell.getColumnSpan());
+    }
 }
