@@ -1,10 +1,11 @@
 /*****************************************************************************
- * Copyright (c) 2017, 2019 Dirk Fauth.
+ * Copyright (c) 2017, 2020 Dirk Fauth.
  *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *      Dirk Fauth <dirk.fauth@googlemail.com> - Initial API and implementation
@@ -28,9 +29,8 @@ import org.eclipse.nebula.widgets.nattable.dataset.person.Person;
 import org.eclipse.nebula.widgets.nattable.dataset.person.PersonService;
 import org.eclipse.nebula.widgets.nattable.grid.command.ClientAreaResizeCommand;
 import org.eclipse.nebula.widgets.nattable.hideshow.indicator.HideIndicatorConstants;
-import org.eclipse.nebula.widgets.nattable.layer.AbstractDpiConverter;
 import org.eclipse.nebula.widgets.nattable.layer.DataLayer;
-import org.eclipse.nebula.widgets.nattable.layer.IDpiConverter;
+import org.eclipse.nebula.widgets.nattable.layer.FixedScalingDpiConverter;
 import org.eclipse.nebula.widgets.nattable.layer.LabelStack;
 import org.eclipse.nebula.widgets.nattable.layer.command.ConfigureScalingCommand;
 import org.eclipse.nebula.widgets.nattable.reorder.ColumnReorderLayer;
@@ -1036,18 +1036,18 @@ public class ResizeColumnHideShowLayerTest {
     @Test
     public void testHiddenColumnsHaveSkipSearchLabel() {
         LabelStack labels = this.hideShowLayer.getConfigLabelsByPosition(1, 0);
-        assertTrue("LabelStack not empty", labels.getLabels().isEmpty());
+        assertTrue("LabelStack not empty", labels.isEmpty());
 
         this.hideShowLayer.hideColumnPositions(1, 4);
 
         labels = this.hideShowLayer.getConfigLabelsByPosition(1, 0);
-        assertFalse("LabelStack not empty", labels.getLabels().isEmpty());
+        assertFalse("LabelStack not empty", labels.isEmpty());
         assertTrue("skip search label not contained", labels.hasLabel(ISearchStrategy.SKIP_SEARCH_RESULT_LABEL));
 
         this.hideShowLayer.showAllColumns();
 
         labels = this.hideShowLayer.getConfigLabelsByPosition(1, 0);
-        assertTrue("LabelStack not empty", labels.getLabels().isEmpty());
+        assertTrue("LabelStack not empty", labels.isEmpty());
     }
 
     @Test
@@ -1057,15 +1057,7 @@ public class ResizeColumnHideShowLayerTest {
         this.bodyDataLayer.setMinColumnWidth(2, 20);
 
         // enable scaling
-        IDpiConverter dpiConverter = new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                this.dpi = 144;
-            }
-
-        };
-        this.hideShowLayer.doCommand(new ConfigureScalingCommand(dpiConverter, dpiConverter));
+        this.hideShowLayer.doCommand(new ConfigureScalingCommand(new FixedScalingDpiConverter(144)));
 
         // trigger client area calculations
         ClientAreaResizeCommand cmd = new ClientAreaResizeCommand(null);
