@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Dirk Fauth <dirk.fauth@googlemail.com> - Initial API and implementation
@@ -66,7 +68,6 @@ public class SizeConfigPercentageTest {
 
     @Test
     public void sizeOverrideCalculationMode() {
-        // this.sizeConfigCalculationMode.setDistributeRemainingSpace(true);
         this.sizeConfigCalculationMode.setSize(5, 200);
 
         // - we increase position 5 to 200, which means 20%
@@ -74,9 +75,27 @@ public class SizeConfigPercentageTest {
         // - the adjacent position 6 then needs to decrease by 10%
         // as fixDynamicPercentageValues is enabled by default
         // - as a reduction to 0 is not allowed, position 6 is set to 1%
-        // - the value of 1% (10 pixels) are afterwards reduced in the other
-        // positions
-        assertEquals(198, this.sizeConfigCalculationMode.getSize(5));
+        // - the value of 1% (10 pixels) is reduced in the other next
+        // position
+        assertEquals(200, this.sizeConfigCalculationMode.getSize(5));
+        assertEquals(10, this.sizeConfigCalculationMode.getSize(6));
+        assertEquals(90, this.sizeConfigCalculationMode.getSize(7));
+    }
+
+    @Test
+    public void sizeOverrideCalculationModeLeft() {
+        this.sizeConfigCalculationMode.setSize(9, 200);
+
+        // - we increase position 9 to 200, which means 20%
+        // - this is an increase by 10%
+        // - the adjacent position 8 then needs to decrease by 10%
+        // as fixDynamicPercentageValues is enabled by default
+        // - as a reduction to 0 is not allowed, position 8 is set to 1%
+        // - the value of 1% (10 pixels) is reduced in the previous
+        // position
+        assertEquals(200, this.sizeConfigCalculationMode.getSize(9));
+        assertEquals(10, this.sizeConfigCalculationMode.getSize(8));
+        assertEquals(90, this.sizeConfigCalculationMode.getSize(7));
     }
 
     @Test
@@ -1354,15 +1373,8 @@ public class SizeConfigPercentageTest {
         assertEquals(33, scaledSizeConfig.getSize(3));
         assertEquals(134, scaledSizeConfig.getAggregateSize(4));
 
-        scaledSizeConfig.setDpiConverter(new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                // use dpi of 144 which will result in a dpi factor of 1.5
-                this.dpi = 144;
-            }
-
-        });
+        // use dpi of 144 which will result in a dpi factor of 1.5
+        scaledSizeConfig.setDpiConverter(new FixedScalingDpiConverter(144));
 
         scaledSizeConfig.calculatePercentages(201, 4);
 
@@ -1385,15 +1397,8 @@ public class SizeConfigPercentageTest {
         assertEquals(125, scaledSizeConfig.getSize(2));
         assertEquals(375, scaledSizeConfig.getAggregateSize(3));
 
-        scaledSizeConfig.setDpiConverter(new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                // use dpi of 144 which will result in a dpi factor of 1.5
-                this.dpi = 144;
-            }
-
-        });
+        // use dpi of 144 which will result in a dpi factor of 1.5
+        scaledSizeConfig.setDpiConverter(new FixedScalingDpiConverter(144));
 
         scaledSizeConfig.calculatePercentages(563, 3);
 
@@ -1402,4 +1407,229 @@ public class SizeConfigPercentageTest {
         assertEquals(187, scaledSizeConfig.getSize(2));
         assertEquals(563, scaledSizeConfig.getAggregateSize(3));
     }
+
+    @Test
+    public void setSizeMixedScaled() {
+        // use dpi of 144 which will result in a dpi factor of 1.5
+        this.sizeConfigMixedMode.setDpiConverter(new FixedScalingDpiConverter(144));
+        this.sizeConfigMixedMode.calculatePercentages(750, 3);
+
+        assertEquals(150, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(150, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(450, this.sizeConfigMixedMode.getSize(2));
+
+        // resize position 0 to 200
+        this.sizeConfigMixedMode.setSize(0, 200);
+
+        // the position itself needs to be 200
+        assertEquals(300, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(150, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(300, this.sizeConfigMixedMode.getSize(2));
+
+        // as we're in percentage mode, the aggregate size shouldn't have
+        // changed
+        assertEquals(750, this.sizeConfigMixedMode.getAggregateSize(3));
+
+        // resize position 1 to 200
+        this.sizeConfigMixedMode.setSize(1, 200);
+
+        // the position itself needs to be 200
+        assertEquals(300, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(300, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(150, this.sizeConfigMixedMode.getSize(2));
+
+        // as we're in percentage mode, the aggregate size shouldn't have
+        // changed
+        assertEquals(750, this.sizeConfigMixedMode.getAggregateSize(3));
+
+        // resize position 2
+        this.sizeConfigMixedMode.setSize(2, 500);
+
+        // no changes as last column should take remaining space
+        assertEquals(300, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(300, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(150, this.sizeConfigMixedMode.getSize(2));
+
+        // as we're in percentage mode, the aggregate size shouldn't have
+        // changed
+        assertEquals(750, this.sizeConfigMixedMode.getAggregateSize(3));
+    }
+
+    @Test
+    public void setSizeMixedScaled2() {
+        // use dpi of 144 which will result in a dpi factor of 1.5
+        this.sizeConfigMixedMode.setDpiConverter(new FixedScalingDpiConverter(144));
+        this.sizeConfigMixedMode.calculatePercentages(750, 3);
+
+        assertEquals(150, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(150, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(450, this.sizeConfigMixedMode.getSize(2));
+
+        this.sizeConfigMixedMode.setSize(1, 350);
+
+        assertEquals(150, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(525, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(75, this.sizeConfigMixedMode.getSize(2));
+
+        // as we're in percentage mode, the aggregate size shouldn't have
+        // changed
+        assertEquals(750, this.sizeConfigMixedMode.getAggregateSize(3));
+    }
+
+    @Test
+    public void setSizeMixed2() {
+
+        assertEquals(100, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(100, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(300, this.sizeConfigMixedMode.getSize(2));
+
+        this.sizeConfigMixedMode.setSize(1, 350);
+
+        assertEquals(100, this.sizeConfigMixedMode.getSize(0));
+        assertEquals(350, this.sizeConfigMixedMode.getSize(1));
+        assertEquals(50, this.sizeConfigMixedMode.getSize(2));
+
+        // as we're in percentage mode, the aggregate size shouldn't have
+        // changed
+        assertEquals(500, this.sizeConfigMixedMode.getAggregateSize(3));
+    }
+
+    @Test
+    public void shouldInitiallySetSizeAsPercentage() {
+        SizeConfig sizeConfig = new SizeConfig(DEFAULT_SIZE);
+        sizeConfig.setPercentageSizing(true);
+        sizeConfig.setSize(0, 25);
+        sizeConfig.setSize(1, 25);
+        sizeConfig.setSize(2, 50);
+        sizeConfig.calculatePercentages(1000, 3);
+
+        assertEquals(250, sizeConfig.getSize(0));
+        assertEquals(250, sizeConfig.getSize(1));
+        assertEquals(500, sizeConfig.getSize(2));
+    }
+
+    @Test
+    public void shouldInitiallySetSizeAsPercentageAfter() {
+        SizeConfig sizeConfig = new SizeConfig(DEFAULT_SIZE);
+        sizeConfig.setSize(0, 25);
+        sizeConfig.setSize(1, 25);
+        sizeConfig.setSize(2, 50);
+        sizeConfig.setPercentageSizing(true);
+        sizeConfig.calculatePercentages(1000, 3);
+
+        assertEquals(250, sizeConfig.getSize(0));
+        assertEquals(250, sizeConfig.getSize(1));
+        assertEquals(500, sizeConfig.getSize(2));
+    }
+
+    @Test
+    public void shouldKeepConsistentPercentagesOnExceedingSpace() {
+        SizeConfig sizeConfig = new SizeConfig(DEFAULT_SIZE);
+        sizeConfig.setPercentageSizing(true);
+        sizeConfig.calculatePercentages(900, 3);
+
+        assertEquals(300, sizeConfig.getSize(0));
+        assertEquals(300, sizeConfig.getSize(1));
+        assertEquals(300, sizeConfig.getSize(2));
+
+        // resize column 0 to be larger than available
+        sizeConfig.setSize(0, 1000);
+
+        assertEquals(882, sizeConfig.getSize(0));
+        assertEquals(9, sizeConfig.getSize(1));
+        assertEquals(9, sizeConfig.getSize(2));
+
+        // resize column 0 to 300
+        sizeConfig.setSize(0, 300);
+
+        assertEquals(300, sizeConfig.getSize(0));
+        assertEquals(591, sizeConfig.getSize(1));
+        assertEquals(9, sizeConfig.getSize(2));
+
+        // resize column 1 to 300
+        sizeConfig.setSize(1, 300);
+
+        assertEquals(300, sizeConfig.getSize(0));
+        assertEquals(300, sizeConfig.getSize(1));
+        assertEquals(300, sizeConfig.getSize(2));
+
+        // increase column 1 by 9 pixels (1%)
+        sizeConfig.setSize(1, 309);
+
+        assertEquals(300, sizeConfig.getSize(0));
+        assertEquals(309, sizeConfig.getSize(1));
+        assertEquals(291, sizeConfig.getSize(2));
+    }
+    
+    @Test
+    public void shouldResizeCorrectlyAfterResizeOfFixedPosition() {
+        SizeConfig sizeConfig = new SizeConfig(DEFAULT_SIZE);
+        
+        /*
+            Name ... 20%
+            Data Type ... 20 %
+            Comment ... rest
+            Scope ... fixed (80px)
+            ID .. 15%
+            Unit .. fixed (50px)
+            Value .. 10%
+            Min value .. 10%
+            Max value .. 10%
+            User level .. fixed (100px)
+            Active ... fixed (50 px)
+         */
+        
+        sizeConfig.setPercentage(0, 20);
+        sizeConfig.setPercentage(1, 20);
+        sizeConfig.setPercentageSizing(2, true);
+        sizeConfig.setPercentageSizing(3, false);
+        sizeConfig.setSize(3, 80);
+        sizeConfig.setPercentage(4, 15);
+        sizeConfig.setPercentageSizing(5, false);
+        sizeConfig.setSize(5, 50);
+        sizeConfig.setPercentage(6, 10);
+        sizeConfig.setPercentage(7, 10);
+        sizeConfig.setPercentage(8, 10);
+        sizeConfig.setPercentageSizing(9, false);
+        sizeConfig.setSize(9, 100);
+        sizeConfig.setPercentageSizing(10, false);
+        sizeConfig.setSize(10, 50);
+        
+        // set percentage sizing globally at the end
+        sizeConfig.setPercentageSizing(true);
+        
+        sizeConfig.calculatePercentages(1280, 11);
+        
+        assertEquals(200, sizeConfig.getSize(0));
+        assertEquals(200, sizeConfig.getSize(1));
+        assertEquals(150, sizeConfig.getSize(2));
+        assertEquals(80, sizeConfig.getSize(3));
+        assertEquals(150, sizeConfig.getSize(4));
+        assertEquals(50, sizeConfig.getSize(5));
+        assertEquals(100, sizeConfig.getSize(6));
+        assertEquals(100, sizeConfig.getSize(7));
+        assertEquals(100, sizeConfig.getSize(8));
+        assertEquals(100, sizeConfig.getSize(9));
+        assertEquals(50, sizeConfig.getSize(10));
+        
+        // resize unit (fixed) and ensure that value (percentage) shrinks
+        sizeConfig.setSize(5, 100);
+        
+        assertEquals(100, sizeConfig.getSize(5));
+        assertEquals(50, sizeConfig.getSize(6));
+        
+        sizeConfig.setSize(5, 50);
+        
+        assertEquals(50, sizeConfig.getSize(5));
+        assertEquals(100, sizeConfig.getSize(6));
+        
+        // verify resize of percentage column is still correct
+        sizeConfig.setSize(0, 300);
+        assertEquals(300, sizeConfig.getSize(0));
+        assertEquals(100, sizeConfig.getSize(1));
+        sizeConfig.setSize(0, 200);
+        assertEquals(200, sizeConfig.getSize(0));
+        assertEquals(200, sizeConfig.getSize(1));
+
+    }
 }
