@@ -1,10 +1,11 @@
 /*****************************************************************************
- * Copyright (c) 2015 CEA LIST.
+ * Copyright (c) 2015, 2020 CEA LIST.
  *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *      Dirk Fauth <dirk.fauth@googlemail.com> - Initial API and implementation
@@ -252,7 +253,8 @@ public class ConfigLabelProviderTest {
                 new FilterRowHeaderComposite<Person>(
                         new IFilterStrategy<Person>() {
                             @Override
-                            public void applyFilter(Map<Integer, Object> filterIndexToObjectMap) {}
+                            public void applyFilter(Map<Integer, Object> filterIndexToObjectMap) {
+                            }
                         },
                         new SortHeaderLayer<Person>(
                                 new ColumnHeaderLayer(this.columnHeaderDataLayer, this.bodyDataLayer, selectionLayer),
@@ -300,16 +302,6 @@ public class ConfigLabelProviderTest {
         TreeLayer treeLayer = new TreeLayer(selectionLayer, new TreeRowModel<Person>(
                 new ITreeData<Person>() {
 
-                    @Override
-                    public String formatDataForDepth(int depth, Person object) {
-                        return null;
-                    }
-
-                    @Override
-                    public String formatDataForDepth(int depth, int index) {
-                        return null;
-                    }
-
                     @Override
                     public int getDepthOfData(Person object) {
                         return 0;
