@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2017 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -22,7 +24,7 @@ import org.eclipse.nebula.widgets.nattable.grid.command.ClientAreaResizeCommand;
 import org.eclipse.nebula.widgets.nattable.layer.ILayerListener;
 import org.eclipse.nebula.widgets.nattable.layer.event.ILayerEvent;
 import org.eclipse.nebula.widgets.nattable.search.CellValueAsStringComparator;
-import org.eclipse.nebula.widgets.nattable.search.ISearchDirection;
+import org.eclipse.nebula.widgets.nattable.search.SearchDirection;
 import org.eclipse.nebula.widgets.nattable.search.event.SearchEvent;
 import org.eclipse.nebula.widgets.nattable.search.strategy.GridSearchStrategy;
 import org.eclipse.nebula.widgets.nattable.search.strategy.SelectionSearchStrategy;
@@ -113,7 +115,7 @@ public class SearchGridCommandHandlerTest {
                     this.searchText,
                     selectionLayer,
                     gridSearchStrategy,
-                    this.isForward ? ISearchDirection.SEARCH_FORWARD : ISearchDirection.SEARCH_BACKWARDS,
+                    this.isForward ? SearchDirection.SEARCH_FORWARD : SearchDirection.SEARCH_BACKWARDS,
                     this.isWrapSearch,
                     this.isCaseSensitive,
                     this.isWholeWord,
@@ -169,7 +171,7 @@ public class SearchGridCommandHandlerTest {
                     this.searchText,
                     selectionLayer,
                     gridSearchStrategy,
-                    this.isForward ? ISearchDirection.SEARCH_FORWARD : ISearchDirection.SEARCH_BACKWARDS,
+                    this.isForward ? SearchDirection.SEARCH_FORWARD : SearchDirection.SEARCH_BACKWARDS,
                     this.isWrapSearch,
                     this.isCaseSensitive,
                     this.isWholeWord,
@@ -421,7 +423,8 @@ public class SearchGridCommandHandlerTest {
             this.expected = null;
             doTest();
             Assert.fail("Invalid regex didn't throw as expected");
-        } catch (PatternSyntaxException e) {}
+        } catch (PatternSyntaxException e) {
+        }
     }
 
     @Test
