@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2019 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -26,12 +28,12 @@ import org.eclipse.nebula.widgets.nattable.dataset.fixture.data.PricingTypeBean;
 import org.eclipse.nebula.widgets.nattable.dataset.fixture.data.RowDataFixture;
 import org.eclipse.nebula.widgets.nattable.dataset.fixture.data.RowDataListFixture;
 import org.eclipse.nebula.widgets.nattable.hideshow.ColumnHideShowLayer;
-import org.eclipse.nebula.widgets.nattable.layer.AbstractDpiConverter;
 import org.eclipse.nebula.widgets.nattable.layer.DataLayer;
-import org.eclipse.nebula.widgets.nattable.layer.IDpiConverter;
+import org.eclipse.nebula.widgets.nattable.layer.FixedScalingDpiConverter;
 import org.eclipse.nebula.widgets.nattable.layer.ILayer;
 import org.eclipse.nebula.widgets.nattable.layer.IUniqueIndexLayer;
 import org.eclipse.nebula.widgets.nattable.layer.LabelStack;
+import org.eclipse.nebula.widgets.nattable.layer.NoScalingDpiConverter;
 import org.eclipse.nebula.widgets.nattable.layer.cell.AbstractOverrider;
 import org.eclipse.nebula.widgets.nattable.layer.cell.ColumnOverrideLabelAccumulator;
 import org.eclipse.nebula.widgets.nattable.layer.command.ConfigureScalingCommand;
@@ -90,6 +92,8 @@ public class SummaryRowIntegrationTest {
         this.natTable.addConfiguration(new TestSummaryRowConfiguration());
 
         this.natTable.configure();
+
+        this.natTable.doCommand(new ConfigureScalingCommand(new NoScalingDpiConverter()));
     }
 
     @Test
@@ -216,15 +220,7 @@ public class SummaryRowIntegrationTest {
 
     @Test
     public void shouldResizeSummaryRowWithoutDownScale() {
-        IDpiConverter dpiConverter = new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                this.dpi = 120;
-            }
-
-        };
-        this.natTable.doCommand(new ConfigureScalingCommand(dpiConverter, dpiConverter));
+        this.natTable.doCommand(new ConfigureScalingCommand(new FixedScalingDpiConverter(120)));
 
         // scaling enabled, therefore default height of 20 pixels is up scaled
         // to 25
@@ -240,15 +236,7 @@ public class SummaryRowIntegrationTest {
 
     @Test
     public void shouldResizeSummaryRowWithDownScale() {
-        IDpiConverter dpiConverter = new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                this.dpi = 120;
-            }
-
-        };
-        this.natTable.doCommand(new ConfigureScalingCommand(dpiConverter, dpiConverter));
+        this.natTable.doCommand(new ConfigureScalingCommand(new FixedScalingDpiConverter(120)));
 
         // scaling enabled, therefore default height of 20 pixels is up scaled
         // to 25
@@ -281,15 +269,7 @@ public class SummaryRowIntegrationTest {
 
     @Test
     public void shouldHandleMultiRowResizeForSummaryRowAndOthersWithoutDownScale() {
-        IDpiConverter dpiConverter = new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                this.dpi = 120;
-            }
-
-        };
-        this.natTable.doCommand(new ConfigureScalingCommand(dpiConverter, dpiConverter));
+        this.natTable.doCommand(new ConfigureScalingCommand(new FixedScalingDpiConverter(120)));
 
         this.natTable.doCommand(new MultiRowResizeCommand(this.natTable, new int[] { 0, 2, 4 }, new int[] { 40, 60, 100 }));
 
@@ -302,15 +282,7 @@ public class SummaryRowIntegrationTest {
 
     @Test
     public void shouldHandleMultiRowResizeForSummaryRowAndOthersWithDownScale() {
-        IDpiConverter dpiConverter = new AbstractDpiConverter() {
-
-            @Override
-            protected void readDpiFromDisplay() {
-                this.dpi = 120;
-            }
-
-        };
-        this.natTable.doCommand(new ConfigureScalingCommand(dpiConverter, dpiConverter));
+        this.natTable.doCommand(new ConfigureScalingCommand(new FixedScalingDpiConverter(120)));
 
         this.natTable.doCommand(new MultiRowResizeCommand(this.natTable, new int[] { 0, 2, 4 }, new int[] { 40, 60, 100 }, true));
 
@@ -329,11 +301,10 @@ public class SummaryRowIntegrationTest {
     @Test
     public void defaultConfigLabelsAreApplied() {
         LabelStack configLabels = this.natTable.getConfigLabelsByPosition(0, 4);
-        List<String> labels = configLabels.getLabels();
 
-        assertEquals(2, labels.size());
-        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_COLUMN_CONFIG_LABEL_PREFIX + 0, labels.get(0));
-        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_ROW_CONFIG_LABEL, labels.get(1));
+        assertEquals(2, configLabels.size());
+        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_COLUMN_CONFIG_LABEL_PREFIX + 0, configLabels.get(0));
+        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_ROW_CONFIG_LABEL, configLabels.get(1));
     }
 
     @Test
@@ -343,12 +314,11 @@ public class SummaryRowIntegrationTest {
         ((ViewportLayer) this.layerStackWithSummary).setConfigLabelAccumulator(labelAcc);
 
         LabelStack configLabels = this.natTable.getConfigLabelsByPosition(0, 4);
-        List<String> labels = configLabels.getLabels();
 
-        assertEquals(3, labels.size());
-        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_COLUMN_CONFIG_LABEL_PREFIX + 0, labels.get(0));
-        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_ROW_CONFIG_LABEL, labels.get(1));
-        assertEquals("myLabel", labels.get(2));
+        assertEquals(3, configLabels.size());
+        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_COLUMN_CONFIG_LABEL_PREFIX + 0, configLabels.get(0));
+        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_ROW_CONFIG_LABEL, configLabels.get(1));
+        assertEquals("myLabel", configLabels.get(2));
     }
 
     @Test
@@ -363,17 +333,15 @@ public class SummaryRowIntegrationTest {
         });
 
         LabelStack configLabels = this.natTable.getConfigLabelsByPosition(0, 4);
-        List<String> labels = configLabels.getLabels();
 
-        assertEquals(2, labels.size());
-        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_COLUMN_CONFIG_LABEL_PREFIX + 0, labels.get(0));
-        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_ROW_CONFIG_LABEL, labels.get(1));
+        assertEquals(2, configLabels.size());
+        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_COLUMN_CONFIG_LABEL_PREFIX + 0, configLabels.get(0));
+        assertEquals(SummaryRowLayer.DEFAULT_SUMMARY_ROW_CONFIG_LABEL, configLabels.get(1));
 
         configLabels = this.natTable.getConfigLabelsByPosition(0, 3);
-        labels = configLabels.getLabels();
 
-        assertEquals(1, labels.size());
-        assertTrue("Label in default body does not start with myLabel", labels.get(0).startsWith("myLabel"));
+        assertEquals(1, configLabels.size());
+        assertTrue("Label in default body does not start with myLabel", configLabels.get(0).startsWith("myLabel"));
     }
 
     @Test
