@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -16,9 +18,9 @@ import org.eclipse.swt.graphics.Color;
 
 public class BorderStyleFixture extends BorderStyle {
 
-    public static int THICKNESS = 2;
-    public static Color COLOR = GUIHelper.COLOR_GREEN;
-    public static LineStyleEnum LINE_STYLE = LineStyleEnum.DASHDOT;
+    public static final int THICKNESS = 2;
+    public static final Color COLOR = GUIHelper.COLOR_GREEN;
+    public static final LineStyleEnum LINE_STYLE = LineStyleEnum.DASHDOT;
 
     public BorderStyleFixture() {
         super(2, COLOR, LINE_STYLE);
