@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2013 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -16,7 +18,6 @@ import java.util.StringTokenizer;
 
 import org.eclipse.nebula.widgets.nattable.command.ILayerCommand;
 import org.eclipse.nebula.widgets.nattable.command.ILayerCommandHandler;
-import org.eclipse.nebula.widgets.nattable.config.ConfigRegistry;
 import org.eclipse.nebula.widgets.nattable.config.IConfigRegistry;
 import org.eclipse.nebula.widgets.nattable.coordinate.Range;
 import org.eclipse.nebula.widgets.nattable.layer.ILayer;
@@ -29,6 +30,7 @@ import org.eclipse.nebula.widgets.nattable.layer.event.ILayerEvent;
 import org.eclipse.nebula.widgets.nattable.painter.cell.ICellPainter;
 import org.eclipse.nebula.widgets.nattable.painter.layer.ILayerPainter;
 import org.eclipse.nebula.widgets.nattable.persistence.IPersistable;
+import org.eclipse.nebula.widgets.nattable.style.DisplayMode;
 import org.eclipse.nebula.widgets.nattable.ui.binding.UiBindingRegistry;
 import org.eclipse.nebula.widgets.nattable.util.IClientAreaProvider;
 import org.eclipse.swt.graphics.Rectangle;
@@ -54,7 +56,7 @@ public class TestLayer implements IUniqueIndexLayer {
 
     private final ILayerCell[][] cells;
     private final Rectangle[][] bounds;
-    private final String[][] displayModes;
+    private final DisplayMode[][] displayModes;
     private final String[][] configLabels;
     private final Object[][] dataValues;
 
@@ -85,7 +87,7 @@ public class TestLayer implements IUniqueIndexLayer {
 
         this.cells = new ILayerCell[columnCount][rowCount];
         this.bounds = new Rectangle[columnCount][rowCount];
-        this.displayModes = new String[columnCount][rowCount];
+        this.displayModes = new DisplayMode[columnCount][rowCount];
         this.configLabels = new String[columnCount][rowCount];
         this.dataValues = new Object[columnCount][rowCount];
 
@@ -357,7 +359,7 @@ public class TestLayer implements IUniqueIndexLayer {
                             break;
                         } else {
                             // Parse display mode
-                            this.displayModes[columnPosition][rowPosition] = nextToken;
+                            this.displayModes[columnPosition][rowPosition] = DisplayMode.valueOf(nextToken);
                         }
                     } else if (":".equals(token)) {
                         String nextToken = cellInfoFieldTokenizer.nextToken()
@@ -440,8 +442,7 @@ public class TestLayer implements IUniqueIndexLayer {
     }
 
     @Override
-    public void configure(ConfigRegistry configRegistry,
-            UiBindingRegistry uiBindingRegistry) {
+    public void configure(IConfigRegistry configRegistry, UiBindingRegistry uiBindingRegistry) {
         // Do nothing
     }
 
@@ -748,7 +749,7 @@ public class TestLayer implements IUniqueIndexLayer {
     }
 
     @Override
-    public String getDisplayModeByPosition(int columnPosition, int rowPosition) {
+    public DisplayMode getDisplayModeByPosition(int columnPosition, int rowPosition) {
         return this.displayModes[columnPosition][rowPosition];
     }
 
