@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -12,8 +14,7 @@ package org.eclipse.nebula.widgets.nattable.test.fixture.command;
 
 import org.eclipse.nebula.widgets.nattable.command.AbstractLayerCommandHandler;
 
-public class CommandHandlerFixture extends
-        AbstractLayerCommandHandler<LayerCommandFixture> {
+public class CommandHandlerFixture extends AbstractLayerCommandHandler<LayerCommandFixture> {
 
     private LayerCommandFixture lastCommandHandled;
 
