@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -19,8 +21,8 @@ import static org.junit.Assert.assertTrue;
 import java.util.Arrays;
 
 import org.eclipse.nebula.widgets.nattable.config.CellConfigAttributes;
-import org.eclipse.nebula.widgets.nattable.config.ConfigRegistry;
 import org.eclipse.nebula.widgets.nattable.config.DefaultNatTableStyleConfiguration;
+import org.eclipse.nebula.widgets.nattable.config.IConfigRegistry;
 import org.eclipse.nebula.widgets.nattable.config.IEditableRule;
 import org.eclipse.nebula.widgets.nattable.coordinate.PositionCoordinate;
 import org.eclipse.nebula.widgets.nattable.data.IDataProvider;
@@ -31,7 +33,6 @@ import org.eclipse.nebula.widgets.nattable.data.validate.DataValidator;
 import org.eclipse.nebula.widgets.nattable.data.validate.IDataValidator;
 import org.eclipse.nebula.widgets.nattable.dataset.fixture.data.PricingTypeBean;
 import org.eclipse.nebula.widgets.nattable.dataset.fixture.data.RowDataListFixture;
-import org.eclipse.nebula.widgets.nattable.edit.ActiveCellEditorRegistry;
 import org.eclipse.nebula.widgets.nattable.edit.EditConfigAttributes;
 import org.eclipse.nebula.widgets.nattable.edit.command.EditCellCommand;
 import org.eclipse.nebula.widgets.nattable.edit.command.EditUtils;
@@ -49,8 +50,10 @@ import org.eclipse.nebula.widgets.nattable.grid.layer.DefaultGridLayer;
 import org.eclipse.nebula.widgets.nattable.layer.CompositeLayer;
 import org.eclipse.nebula.widgets.nattable.layer.DataLayer;
 import org.eclipse.nebula.widgets.nattable.layer.ILayerListener;
+import org.eclipse.nebula.widgets.nattable.layer.NoScalingDpiConverter;
 import org.eclipse.nebula.widgets.nattable.layer.SpanningDataLayer;
 import org.eclipse.nebula.widgets.nattable.layer.cell.ILayerCell;
+import org.eclipse.nebula.widgets.nattable.layer.command.ConfigureScalingCommand;
 import org.eclipse.nebula.widgets.nattable.layer.event.ILayerEvent;
 import org.eclipse.nebula.widgets.nattable.layer.stack.DummyGridLayerStack;
 import org.eclipse.nebula.widgets.nattable.painter.cell.CheckBoxPainter;
@@ -71,7 +74,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
-@SuppressWarnings("deprecation")
 public class EditIntegrationTest {
 
     private static final String TEST_LABEL = "testLabel";
@@ -87,23 +89,16 @@ public class EditIntegrationTest {
     public void setup() {
         this.gridLayerStack = new DummyGridLayerStack(5, 5);
         this.natTable = new NatTableFixture(this.gridLayerStack);
+        this.natTable.doCommand(new ConfigureScalingCommand(new NoScalingDpiConverter()));
 
         // Ensure no active editor (static) is present
-        // Although deprecated this needs to still work for backwards
-        // compatibility
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     @After
     public void tearDown() {
         // ensure the editor is closed
         this.natTable.commitAndCloseActiveCellEditor();
-        // as the test processing is too fast, we also need to unregister
-        // because the registry
-        // is only cleaned on disposal of the editor control, which might not
-        // happen in the tests
-        ActiveCellEditorRegistry.unregisterActiveCellEditor();
     }
 
     @Test
@@ -113,7 +108,6 @@ public class EditIntegrationTest {
                 .getConfigRegistry(), cell));
 
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     @Test
@@ -152,7 +146,6 @@ public class EditIntegrationTest {
                 this.natTable.getCellByPosition(4,
                         COLUMN_HEADER_ROW_COUNT + 2)));
         assertNotNull(this.natTable.getActiveCellEditor());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor());
 
         this.natTable.doCommand(new EditCellCommand(this.natTable, this.natTable
                 .getConfigRegistry(),
@@ -160,8 +153,6 @@ public class EditIntegrationTest {
                         COLUMN_HEADER_ROW_COUNT + 3)));
         assertNotNull(this.natTable.getActiveCellEditor());
         assertFalse(this.natTable.getActiveCellEditor().isClosed());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor());
-        assertFalse(ActiveCellEditorRegistry.getActiveCellEditor().isClosed());
     }
 
     @Test
@@ -183,7 +174,6 @@ public class EditIntegrationTest {
         // ActiveCellEditor should be closed if a ColumnResizeCommand is
         // executed and the editor loses focus
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     @Test
@@ -228,6 +218,41 @@ public class EditIntegrationTest {
         this.natTable.enableEditingOnAllCells();
         this.natTable.doCommand(new SelectCellCommand(this.natTable, 1, 1, false, false));
 
+        // Edit cell
+        ILayerCell cell = this.natTable.getCellByPosition(1, 1);
+        this.natTable.doCommand(new EditCellCommand(this.natTable, this.natTable
+                .getConfigRegistry(), cell));
+
+        // Press tab
+        Text textControl = ((Text) this.natTable.getActiveCellEditor()
+                .getEditorControl());
+        assertEquals("Col: 1, Row: 1", textControl.getText());
+
+        textControl.notifyListeners(SWT.Traverse, SWTUtils.keyEvent(SWT.TAB));
+
+        // Verify new cell selection
+        PositionCoordinate lastSelectedCellPosition = this.gridLayerStack
+                .getBodyLayer().getSelectionLayer().getSelectionAnchor();
+        assertEquals(1, lastSelectedCellPosition.columnPosition);
+        assertEquals(0, lastSelectedCellPosition.rowPosition);
+
+        // Verify that the traversed cell is being edited
+        assertNotNull(this.natTable.getActiveCellEditor());
+        textControl = ((Text) this.natTable.getActiveCellEditor().getEditorControl());
+        assertEquals("Col: 2, Row: 1", textControl.getText());
+    }
+
+    @Test
+    public void navigationWithTabNoActivate() throws Exception {
+        this.natTable.enableEditingOnAllCells();
+
+        // disable activation on traversal
+        this.natTable.getConfigRegistry().registerConfigAttribute(
+                EditConfigAttributes.ACTIVATE_EDITOR_ON_TRAVERSAL,
+                Boolean.FALSE);
+
+        this.natTable.doCommand(new SelectCellCommand(this.natTable, 1, 1, false, false));
+
         // Edit cell
         ILayerCell cell = this.natTable.getCellByPosition(1, 1);
         this.natTable.doCommand(new EditCellCommand(this.natTable, this.natTable
@@ -250,7 +275,6 @@ public class EditIntegrationTest {
 
         // Verify that no cell is being edited
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     @Test
@@ -288,10 +312,6 @@ public class EditIntegrationTest {
         assertEquals(textControl, this.natTable.getActiveCellEditor()
                 .getEditorControl());
         assertEquals("AA", this.natTable.getActiveCellEditor().getCanonicalValue());
-        assertEquals(textControl, ActiveCellEditorRegistry
-                .getActiveCellEditor().getEditorControl());
-        assertEquals("AA", ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue());
     }
 
     @Test
@@ -304,9 +324,6 @@ public class EditIntegrationTest {
         // Verify edit mode
         assertNotNull(this.natTable.getActiveCellEditor());
         assertEquals("A", this.natTable.getActiveCellEditor().getCanonicalValue());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor());
-        assertEquals("A", ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue());
     }
 
     @Test
@@ -334,19 +351,11 @@ public class EditIntegrationTest {
         // Value not committed
         assertNotNull(this.natTable.getActiveCellEditor().getEditorControl());
         assertEquals("A", this.natTable.getActiveCellEditor().getCanonicalValue());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor()
-                .getEditorControl());
-        assertEquals("A", ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue());
 
         // Enter a valid value - 'C'
         this.natTable.notifyListeners(SWT.KeyDown, SWTUtils.keyEventWithChar('C'));
         assertNotNull(this.natTable.getActiveCellEditor().getEditorControl());
         assertEquals("C", this.natTable.getActiveCellEditor().getCanonicalValue());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor()
-                .getEditorControl());
-        assertEquals("C", ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue());
 
         // Press 'Enter' again
         this.natTable.getActiveCellEditor().getEditorControl()
@@ -355,7 +364,6 @@ public class EditIntegrationTest {
         // Value committed and editor closed
         assertEquals("C", this.natTable.getCellByPosition(1, 1).getDataValue());
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     @Test
@@ -365,6 +373,7 @@ public class EditIntegrationTest {
                 RowDataListFixture.getPropertyNames(),
                 RowDataListFixture.getPropertyToLabelMap());
         this.natTable = new NatTableFixture(layerStack, 1200, 300, false);
+        this.natTable.doCommand(new ConfigureScalingCommand(new NoScalingDpiConverter()));
 
         // Enable editing
         this.natTable.enableEditingOnAllCells();
@@ -411,9 +420,6 @@ public class EditIntegrationTest {
         // Verify edit mode
         assertNotNull(this.natTable.getActiveCellEditor());
         assertEquals("A", this.natTable.getActiveCellEditor().getCanonicalValue());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor());
-        assertEquals("A", ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue());
 
         // Press ESC
         SWTUtils.pressKeyOnControl(SWT.ESC, this.natTable.getActiveCellEditor()
@@ -421,7 +427,6 @@ public class EditIntegrationTest {
 
         // Verify state
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
         assertEquals("Col: 1, Row: 1", this.natTable.getDataValueByPosition(1, 1));
     }
 
@@ -436,6 +441,7 @@ public class EditIntegrationTest {
                 RowDataListFixture.getPropertyNames(),
                 RowDataListFixture.getPropertyToLabelMap());
         this.natTable = new NatTableFixture(layerStack, 1200, 300, false);
+        this.natTable.doCommand(new ConfigureScalingCommand(new NoScalingDpiConverter()));
 
         // Enable editing
         this.natTable.enableEditingOnAllCells();
@@ -474,10 +480,6 @@ public class EditIntegrationTest {
         assertTrue(this.natTable.getActiveCellEditor().getCanonicalValue() instanceof PricingTypeBean);
         assertEquals("MN", this.natTable.getActiveCellEditor().getCanonicalValue()
                 .toString());
-        assertTrue(ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue() instanceof PricingTypeBean);
-        assertEquals("MN", ActiveCellEditorRegistry.getActiveCellEditor()
-                .getCanonicalValue().toString());
 
         // Click - expand select value 'Automatic'
         combo.select(1);
@@ -488,7 +490,6 @@ public class EditIntegrationTest {
                 this.natTable.getDataValueByPosition(columnPosition, rowPosition)
                         .toString());
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     @Test
@@ -527,9 +528,6 @@ public class EditIntegrationTest {
         assertNotNull(this.natTable.getActiveCellEditor());
         assertEquals("Col: 1, Row: 1", this.natTable.getActiveCellEditor()
                 .getCanonicalValue());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor());
-        assertEquals("Col: 1, Row: 1", ActiveCellEditorRegistry
-                .getActiveCellEditor().getCanonicalValue());
 
         // verify that inline editing is used and not dialog
         assertTrue("No InlineCellEditEvent fired", inlineFired[0]);
@@ -584,7 +582,8 @@ public class EditIntegrationTest {
         layer.setChildLayer(GridRegion.COLUMN_HEADER, new DataLayer(new IDataProvider() {
 
             @Override
-            public void setDataValue(int columnIndex, int rowIndex, Object newValue) {}
+            public void setDataValue(int columnIndex, int rowIndex, Object newValue) {
+            }
 
             @Override
             public int getRowCount() {
@@ -603,6 +602,7 @@ public class EditIntegrationTest {
         }), 0, 0);
         layer.setChildLayer(GridRegion.BODY, viewportLayer, 0, 1);
         this.natTable = new NatTableFixture(layer, 1200, 300, false);
+        this.natTable.doCommand(new ConfigureScalingCommand(new NoScalingDpiConverter()));
 
         layer.addConfiguration(new DefaultEditBindings());
         layer.addConfiguration(new DefaultEditConfiguration());
@@ -639,33 +639,6 @@ public class EditIntegrationTest {
         assertEquals(new Rectangle(1, 20, 198, 39), editorControl.getBounds());
     }
 
-    /**
-     * Test case that ensures that the active editor is also available via the
-     * {@linkplain ActiveCellEditorRegistry}.
-     * <p>
-     * Ensures that the backward compatibility is not broken.
-     * </p>
-     */
-    @Test
-    public void testEditorRegisteredInActiveCellEditorRegistry() {
-        this.natTable.enableEditingOnAllCells();
-
-        ILayerCell cell = this.natTable.getCellByPosition(4, 4);
-        this.natTable.doCommand(new EditCellCommand(this.natTable, this.natTable
-                .getConfigRegistry(), cell));
-
-        assertNotNull(this.natTable.getActiveCellEditor());
-        assertNotNull(ActiveCellEditorRegistry.getActiveCellEditor());
-        assertEquals(this.natTable.getActiveCellEditor(),
-                ActiveCellEditorRegistry.getActiveCellEditor());
-
-        // Close the editor again
-        this.natTable.getActiveCellEditor().getEditorControl()
-                .notifyListeners(SWT.KeyDown, SWTUtils.keyEvent(SWT.CR));
-        assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
-    }
-
     /**
      * Test case that ensures that an editor, which is committed through the
      * {@linkplain EditUtils}, is also removed from the table.
@@ -685,12 +658,11 @@ public class EditIntegrationTest {
         editor.setText("A");
 
         // Close the again
-        EditUtils.commitAndCloseActiveEditor();
+        this.natTable.commitAndCloseActiveCellEditor();
 
         // check if value is saved and editor is gone
         assertEquals("A", this.natTable.getCellByPosition(4, 4).getDataValue());
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     /**
@@ -709,11 +681,10 @@ public class EditIntegrationTest {
                 .getConfigRegistry(), cell));
 
         // close the editor
-        ActiveCellEditorRegistry.getActiveCellEditor().close();
+        this.natTable.getActiveCellEditor().close();
 
         // check if editor is gone
         assertNull(this.natTable.getActiveCellEditor());
-        assertNull(ActiveCellEditorRegistry.getActiveCellEditor());
     }
 
     // *** Convenience methods ***.
@@ -721,7 +692,7 @@ public class EditIntegrationTest {
     // The sane fixtures are used to ensure that the example keeps working
     // without fail
 
-    private static void registerComboBox(ConfigRegistry configRegistry,
+    private static void registerComboBox(IConfigRegistry configRegistry,
             ICellPainter comboBoxCellPainter, ICellEditor comboBoxCellEditor) {
         configRegistry.registerConfigAttribute(
                 CellConfigAttributes.CELL_PAINTER, comboBoxCellPainter,
@@ -739,7 +710,7 @@ public class EditIntegrationTest {
                 TEST_LABEL);
     }
 
-    private static void registerCheckBoxEditor(ConfigRegistry configRegistry,
+    private static void registerCheckBoxEditor(IConfigRegistry configRegistry,
             ICellPainter checkBoxCellPainter, ICellEditor checkBoxCellEditor) {
         configRegistry.registerConfigAttribute(
                 CellConfigAttributes.CELL_PAINTER, checkBoxCellPainter,
