@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2019 Dirk Fauth and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2013, 2020 Dirk Fauth and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -13,14 +15,16 @@ package org.eclipse.nebula.widgets.nattable.filterrow.combobox;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
+import java.util.stream.Collectors;
 
 import org.eclipse.nebula.widgets.nattable.data.IColumnAccessor;
 import org.eclipse.nebula.widgets.nattable.edit.editor.IComboBoxDataProvider;
@@ -69,11 +73,11 @@ public class FilterRowComboBoxDataProvider<T> implements IComboBoxDataProvider,
      * GlazedLists for example, the combobox would only contain the value which
      * is currently used for filtering.
      */
-    private final Map<Integer, List<?>> valueCache = new HashMap<Integer, List<?>>();
+    private final Map<Integer, List<?>> valueCache = new HashMap<>();
     /**
      * List of listeners that get informed if the value cache gets updated.
      */
-    private List<IFilterRowComboUpdateListener> cacheUpdateListener = new ArrayList<IFilterRowComboUpdateListener>();
+    private List<IFilterRowComboUpdateListener> cacheUpdateListener = new ArrayList<>();
     /**
      * Flag to indicate whether the combo box content should be loaded lazily.
      *
@@ -233,49 +237,28 @@ public class FilterRowComboBoxDataProvider<T> implements IComboBoxDataProvider,
      */
     @SuppressWarnings({ "rawtypes", "unchecked" })
     protected List<?> collectValues(int columnIndex) {
-        Set uniqueValues = new HashSet();
+        List result = this.baseCollection.stream()
+                .unordered()
+                .parallel()
+                .map(x -> this.columnAccessor.getDataValue(x, columnIndex))
+                .distinct()
+                .collect(Collectors.toList());
 
-        boolean nullFound = false;
-        for (T rowObject : this.baseCollection) {
-            Object dataValue = this.columnAccessor.getDataValue(rowObject, columnIndex);
-            if (dataValue != null) {
-                uniqueValues.add(dataValue);
-            } else {
-                nullFound = true;
+        Object firstNonNull = result.stream()
+                .filter(Objects::nonNull)
+                .findFirst()
+                .orElse(null);
+        if (firstNonNull instanceof Comparable) {
+            result.sort(Comparator.nullsFirst(Comparator.naturalOrder()));
+        } else {
+            // always ensure that null is at the first position
+            int index = result.indexOf(null);
+            if (index >= 0) {
+                result.remove(index);
+                result.add(0, null);
             }
         }
 
-        List result = new ArrayList(uniqueValues);
-        if (!result.isEmpty() && result.get(0) instanceof Comparable) {
-            Collections.sort(result);
-        }
-
-        if (nullFound) {
-            result.add(0, null);
-        }
-
-        // TODO Java8
-        // List result = this.baseCollection.stream()
-        // .unordered()
-        // .parallel()
-        // .map(x -> this.bodyDataColumnAccessor.getDataValue(x,
-        // columnIndex))
-        // .distinct()
-        // .collect(Collectors.toList());
-        //
-        // Object firstNonNull =
-        // result.stream().filter(Objects::nonNull).findFirst().orElse(null);
-        // if (firstNonNull instanceof Comparable) {
-        // result.sort(nullsFirst(naturalOrder()));
-        // } else {
-        // // always ensure that null is at the first position
-        // int index = result.indexOf(null);
-        // if (index >= 0) {
-        // result.remove(index);
-        // result.add(0, null);
-        // }
-        // }
-
         return result;
     }
 
@@ -309,7 +292,7 @@ public class FilterRowComboBoxDataProvider<T> implements IComboBoxDataProvider,
                 this.valueCacheLock.writeLock().lock();
                 try {
                     // remember the cache before updating
-                    Map<Integer, List<?>> cacheBefore = new HashMap<Integer, List<?>>(this.valueCache);
+                    Map<Integer, List<?>> cacheBefore = new HashMap<>(this.valueCache);
 
                     // perform a refresh of the whole cache
                     this.valueCache.clear();
@@ -347,8 +330,8 @@ public class FilterRowComboBoxDataProvider<T> implements IComboBoxDataProvider,
      *         <code>null</code> if nothing has changed.
      */
     protected FilterRowComboUpdateEvent buildUpdateEvent(int columnIndex, List<?> cacheBefore, List<?> cacheAfter) {
-        Set<Object> addedValues = new HashSet<Object>();
-        Set<Object> removedValues = new HashSet<Object>();
+        Set<Object> addedValues = new HashSet<>();
+        Set<Object> removedValues = new HashSet<>();
 
         // find the added values
         if (cacheAfter != null && cacheBefore != null) {
@@ -403,21 +386,6 @@ public class FilterRowComboBoxDataProvider<T> implements IComboBoxDataProvider,
         this.cacheUpdateListener.add(listener);
     }
 
-    /**
-     * Removes the given listener from the list of listeners for value cache
-     * updates.
-     *
-     * @param listener
-     *            The listener to remove.
-     *
-     * @deprecated typo in method, use
-     *             {@link #removeCacheUpdateListener(IFilterRowComboUpdateListener)}
-     */
-    @Deprecated
-    public void removeCacheUdpateListener(IFilterRowComboUpdateListener listener) {
-        this.cacheUpdateListener.remove(listener);
-    }
-
     /**
      * Removes the given listener from the list of listeners for value cache
      * updates.
