@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -45,6 +47,18 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
     private final ColumnGroupModel model;
     private final ColumnGroupHeaderLayer columnGroupHeaderLayer;
 
+    /**
+     *
+     * @param columnGroupHeaderLayer
+     *            The {@link ColumnGroupHeaderLayer} to stack on.
+     * @param selectionLayer
+     *            unused
+     * @param columnGroupModel
+     *            The {@link ColumnGroupModel} used to build the column groups.
+     *
+     * @deprecated Use constructor without SelectionLayer parameter
+     */
+    @Deprecated
     public ColumnGroupGroupHeaderLayer(
             ColumnGroupHeaderLayer columnGroupHeaderLayer,
             SelectionLayer selectionLayer,
@@ -52,6 +66,21 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
         this(columnGroupHeaderLayer, selectionLayer, columnGroupModel, true);
     }
 
+    /**
+     *
+     * @param columnGroupHeaderLayer
+     *            The {@link ColumnGroupHeaderLayer} to stack on.
+     * @param selectionLayer
+     *            unused
+     * @param columnGroupModel
+     *            The {@link ColumnGroupModel} used to build the column groups.
+     * @param useDefaultConfiguration
+     *            <code>true</code> if the default configuration should be
+     *            applied, <code>false</code> if not.
+     *
+     * @deprecated Use constructor without SelectionLayer parameter
+     */
+    @Deprecated
     public ColumnGroupGroupHeaderLayer(
             ColumnGroupHeaderLayer columnGroupHeaderLayer,
             SelectionLayer selectionLayer,
@@ -68,6 +97,48 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
         }
     }
 
+    /**
+     *
+     * @param columnGroupHeaderLayer
+     *            The {@link ColumnGroupHeaderLayer} to stack on.
+     * @param columnGroupModel
+     *            The {@link ColumnGroupModel} used to build the column groups.
+     *
+     * @since 2.0
+     */
+    public ColumnGroupGroupHeaderLayer(
+            ColumnGroupHeaderLayer columnGroupHeaderLayer,
+            ColumnGroupModel columnGroupModel) {
+        this(columnGroupHeaderLayer, columnGroupModel, true);
+    }
+
+    /**
+     *
+     * @param columnGroupHeaderLayer
+     *            The {@link ColumnGroupHeaderLayer} to stack on.
+     * @param columnGroupModel
+     *            The {@link ColumnGroupModel} used to build the column groups.
+     * @param useDefaultConfiguration
+     *            <code>true</code> if the default configuration should be
+     *            applied, <code>false</code> if not.
+     *
+     * @since 2.0
+     */
+    public ColumnGroupGroupHeaderLayer(
+            ColumnGroupHeaderLayer columnGroupHeaderLayer,
+            ColumnGroupModel columnGroupModel,
+            boolean useDefaultConfiguration) {
+        super(columnGroupHeaderLayer);
+        this.columnGroupHeaderLayer = columnGroupHeaderLayer;
+        this.model = columnGroupModel;
+
+        registerCommandHandler(new ConfigureScalingCommandHandler(null, this.rowHeightConfig));
+
+        if (useDefaultConfiguration) {
+            addConfiguration(new DefaultColumnGroupHeaderLayerConfiguration(columnGroupModel));
+        }
+    }
+
     // Vertical features
 
     // Rows
@@ -242,7 +313,7 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
      *
      * @param columnPosition
      *            position of any column belonging to the group
-     *
+     * @return the column span
      * @since 1.6
      */
     public int getColumnSpan(int columnPosition) {
@@ -314,7 +385,7 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
     }
 
     @Override
-    public String getDisplayModeByPosition(int columnPosition, int rowPosition) {
+    public DisplayMode getDisplayModeByPosition(int columnPosition, int rowPosition) {
         int columnIndex = getColumnIndexByPosition(columnPosition);
         if (rowPosition == 0 && this.model.isPartOfAGroup(columnIndex)) {
             return DisplayMode.NORMAL;
@@ -397,9 +468,6 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
         return this.model.isPartOfAGroup(bodyColumnIndex);
     }
 
-    /**
-     * @see ColumnGroup#setUnbreakable(boolean)
-     */
     public void setGroupUnbreakable(int columnIndex) {
         ColumnGroup columnGroup = this.model.getColumnGroupByIndex(columnIndex);
         columnGroup.setUnbreakable(true);
@@ -422,8 +490,7 @@ public class ColumnGroupGroupHeaderLayer extends AbstractLayerTransform {
         labels.add(DefaultColumnGroupHeaderLayerConfiguration.GROUP_EXPANDED_CONFIG_TYPE);
 
         // add the labels configured via IConfigLabelAccumulator
-        if (getConfigLabelAccumulator() != null
-                && getConfigLabelAccumulator() instanceof IConfigLabelProvider) {
+        if (getConfigLabelAccumulator() instanceof IConfigLabelProvider) {
             labels.addAll(((IConfigLabelProvider) getConfigLabelAccumulator()).getProvidedLabels());
         }
 
