@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -16,12 +18,10 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Map;
 import java.util.Properties;
 
 import org.eclipse.nebula.widgets.nattable.command.AbstractRegionCommand;
 import org.eclipse.nebula.widgets.nattable.command.ILayerCommand;
-import org.eclipse.nebula.widgets.nattable.config.ConfigRegistry;
 import org.eclipse.nebula.widgets.nattable.config.IConfigRegistry;
 import org.eclipse.nebula.widgets.nattable.coordinate.Range;
 import org.eclipse.nebula.widgets.nattable.layer.cell.AggregateConfigLabelAccumulator;
@@ -31,8 +31,8 @@ import org.eclipse.nebula.widgets.nattable.layer.cell.ILayerCell;
 import org.eclipse.nebula.widgets.nattable.layer.cell.TranslatedLayerCell;
 import org.eclipse.nebula.widgets.nattable.painter.cell.ICellPainter;
 import org.eclipse.nebula.widgets.nattable.painter.layer.ILayerPainter;
+import org.eclipse.nebula.widgets.nattable.style.DisplayMode;
 import org.eclipse.nebula.widgets.nattable.ui.binding.UiBindingRegistry;
-import org.eclipse.nebula.widgets.nattable.util.IClientAreaProvider;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
@@ -50,10 +50,10 @@ public class CompositeLayer extends AbstractLayer {
 
     private final int layoutYCount;
 
-    private final Map<ILayer, String> childLayerToRegionNameMap = new HashMap<ILayer, String>();
-    private final Map<String, ILayer> regionNameToChildLayerMap = new HashMap<String, ILayer>();
+    private final HashMap<ILayer, String> childLayerToRegionNameMap = new HashMap<>();
+    private final HashMap<String, ILayer> regionNameToChildLayerMap = new HashMap<>();
 
-    private final Map<String, IConfigLabelAccumulator> regionNameToConfigLabelAccumulatorMap = new HashMap<String, IConfigLabelAccumulator>();
+    private final HashMap<String, IConfigLabelAccumulator> regionNameToConfigLabelAccumulatorMap = new HashMap<>();
 
     /** Data struct. for child Layers */
     private final ILayer[][] childLayerLayout;
@@ -115,7 +115,7 @@ public class CompositeLayer extends AbstractLayer {
     // Configuration
 
     @Override
-    public void configure(ConfigRegistry configRegistry, UiBindingRegistry uiBindingRegistry) {
+    public void configure(IConfigRegistry configRegistry, UiBindingRegistry uiBindingRegistry) {
         for (int layoutX = 0; layoutX < this.layoutXCount; layoutX++) {
             for (int layoutY = 0; layoutY < this.layoutYCount; layoutY++) {
                 this.childLayerLayout[layoutX][layoutY].configure(
@@ -233,7 +233,7 @@ public class CompositeLayer extends AbstractLayer {
             return null;
         }
 
-        Collection<Range> localColumnPositionRanges = new ArrayList<Range>(underlyingColumnPositionRanges.size());
+        Collection<Range> localColumnPositionRanges = new ArrayList<>(underlyingColumnPositionRanges.size());
 
         int offset = getColumnPositionOffset(layoutCoordinate.x);
         for (Range underlyingColumnPositionRange : underlyingColumnPositionRanges) {
@@ -322,7 +322,7 @@ public class CompositeLayer extends AbstractLayer {
 
     @Override
     public Collection<ILayer> getUnderlyingLayersByColumnPosition(int columnPosition) {
-        Collection<ILayer> underlyingLayers = new HashSet<ILayer>();
+        Collection<ILayer> underlyingLayers = new HashSet<>();
 
         for (int layoutX = 0; layoutX < this.childLayerLayout.length; layoutX++) {
             int columnPositionOffset = getColumnPositionOffset(layoutX);
@@ -399,7 +399,7 @@ public class CompositeLayer extends AbstractLayer {
             return null;
         }
 
-        Collection<Range> localRowPositionRanges = new ArrayList<Range>(underlyingRowPositionRanges.size());
+        Collection<Range> localRowPositionRanges = new ArrayList<>(underlyingRowPositionRanges.size());
 
         int offset = getRowPositionOffset(layoutCoordinate.y);
         for (Range underlyingRowPositionRange : underlyingRowPositionRanges) {
@@ -491,7 +491,7 @@ public class CompositeLayer extends AbstractLayer {
 
     @Override
     public Collection<ILayer> getUnderlyingLayersByRowPosition(int rowPosition) {
-        Collection<ILayer> underlyingLayers = new HashSet<ILayer>();
+        Collection<ILayer> underlyingLayers = new HashSet<>();
 
         for (int layoutY = 0; layoutY < this.childLayerLayout[0].length; layoutY++) {
             int rowPositionOffset = getRowPositionOffset(layoutY);
@@ -564,7 +564,7 @@ public class CompositeLayer extends AbstractLayer {
     }
 
     @Override
-    public String getDisplayModeByPosition(
+    public DisplayMode getDisplayModeByPosition(
             int compositeColumnPosition, int compositeRowPosition) {
         Point layoutCoordinate = getLayoutXYByPosition(
                 compositeColumnPosition, compositeRowPosition);
@@ -650,12 +650,7 @@ public class CompositeLayer extends AbstractLayer {
         childLayer.addLayerListener(this);
         this.childLayerLayout[layoutX][layoutY] = childLayer;
 
-        childLayer.setClientAreaProvider(new IClientAreaProvider() {
-            @Override
-            public Rectangle getClientArea() {
-                return getChildClientArea(layoutX, layoutY);
-            }
-        });
+        childLayer.setClientAreaProvider(() -> getChildClientArea(layoutX, layoutY));
     }
 
     public IConfigLabelAccumulator getConfigLabelAccumulatorByRegionName(String regionName) {
@@ -665,6 +660,11 @@ public class CompositeLayer extends AbstractLayer {
     /**
      * Sets the IConfigLabelAccumulator for the given named region. Replaces any
      * existing IConfigLabelAccumulator.
+     *
+     * @param regionName
+     *            the region name.
+     * @param configLabelAccumulator
+     *            the {@link IConfigLabelAccumulator} to set.
      */
     public void setConfigLabelAccumulatorForRegion(
             String regionName, IConfigLabelAccumulator configLabelAccumulator) {
@@ -673,6 +673,11 @@ public class CompositeLayer extends AbstractLayer {
 
     /**
      * Adds the configLabelAccumulator to the existing label accumulators.
+     *
+     * @param regionName
+     *            the region name.
+     * @param configLabelAccumulator
+     *            the {@link IConfigLabelAccumulator} to add.
      */
     public void addConfigLabelAccumulatorForRegion(
             String regionName, IConfigLabelAccumulator configLabelAccumulator) {
@@ -696,7 +701,7 @@ public class CompositeLayer extends AbstractLayer {
 
         final Rectangle compositeClientArea = getClientAreaProvider().getClientArea();
 
-        if (childLayer instanceof AbstractLayer && ((AbstractLayer) childLayer).isDynamicSizeLayer()) {
+        if (childLayer.isDynamicSizeLayer()) {
 
             // check if there are further sections to the bottom and reduce the
             // height accordingly necessary in case the current child layer is
@@ -738,9 +743,7 @@ public class CompositeLayer extends AbstractLayer {
                 childLayer.getPreferredWidth(),
                 childLayer.getPreferredHeight());
 
-        final Rectangle intersection = compositeClientArea.intersection(childClientArea);
-
-        return intersection;
+        return compositeClientArea.intersection(childClientArea);
     }
 
     /**
@@ -1010,8 +1013,7 @@ public class CompositeLayer extends AbstractLayer {
     public boolean isDynamicSizeLayer() {
         for (int layoutX = 0; layoutX < this.layoutXCount; layoutX++) {
             for (int layoutY = 0; layoutY < this.layoutYCount; layoutY++) {
-                if (this.childLayerLayout[layoutX][layoutY] instanceof AbstractLayer
-                        && ((AbstractLayer) this.childLayerLayout[layoutX][layoutY]).isDynamicSizeLayer()) {
+                if (this.childLayerLayout[layoutX][layoutY].isDynamicSizeLayer()) {
                     return true;
                 }
             }
@@ -1030,13 +1032,11 @@ public class CompositeLayer extends AbstractLayer {
                 labels.add(regionName);
 
                 IConfigLabelAccumulator accumulator = this.regionNameToConfigLabelAccumulatorMap.get(regionName);
-                if (accumulator != null && accumulator instanceof IConfigLabelProvider) {
+                if (accumulator instanceof IConfigLabelProvider) {
                     labels.addAll(((IConfigLabelProvider) accumulator).getProvidedLabels());
                 }
 
-                if (childLayer instanceof AbstractLayer) {
-                    labels.addAll(((AbstractLayer) childLayer).getProvidedLabels());
-                }
+                labels.addAll(childLayer.getProvidedLabels());
             }
         }
         return labels;
