@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2014, 2018 Jonas Hugo, Markus Wahl.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2014, 2020 Jonas Hugo, Markus Wahl.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Jonas Hugo <Jonas.Hugo@jeppesen.com>,
@@ -16,12 +18,16 @@ package org.eclipse.nebula.widgets.nattable.selection.preserve;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Map;
 
+import org.eclipse.collections.api.map.primitive.MutableIntObjectMap;
+import org.eclipse.collections.api.set.primitive.MutableIntSet;
+import org.eclipse.collections.api.tuple.primitive.IntObjectPair;
+import org.eclipse.collections.impl.factory.primitive.IntObjectMaps;
+import org.eclipse.collections.impl.factory.primitive.IntSets;
+
 /**
  * The selected cells of columns and rows
  *
@@ -33,12 +39,12 @@ class Selections<T> {
     /**
      * A map for looking up rows given their row IDs
      */
-    private Map<Serializable, Row<T>> selectedRows = new HashMap<Serializable, Row<T>>();
+    private HashMap<Serializable, Row<T>> selectedRows = new HashMap<>();
 
     /**
      * A map for looking up columns given their column positions
      */
-    private Map<Integer, Column> selectedColumns = new HashMap<Integer, Column>();
+    private MutableIntObjectMap<Column> selectedColumns = IntObjectMaps.mutable.empty();
 
     /**
      * Select the cell at the intersection of the specified row and column.
@@ -93,17 +99,16 @@ class Selections<T> {
             this.selectedRows.remove(rowId);
         }
 
-        Collection<Integer> toRemove = new HashSet<Integer>();
-        for (Map.Entry<Integer, Column> entry : this.selectedColumns.entrySet()) {
-            entry.getValue().removeItem(rowId);
-            if (!entry.getValue().hasSelection()) {
-                toRemove.add(entry.getKey());
+        MutableIntSet toRemove = IntSets.mutable.empty();
+        for (IntObjectPair<Column> pair : this.selectedColumns.keyValuesView()) {
+            Column column = pair.getTwo();
+            column.removeItem(rowId);
+            if (!column.hasSelection()) {
+                toRemove.add(pair.getOne());
             }
         }
 
-        for (Integer key : toRemove) {
-            this.selectedColumns.remove(key);
-        }
+        toRemove.forEach(this.selectedColumns::remove);
     }
 
     /**
@@ -118,7 +123,7 @@ class Selections<T> {
             this.selectedColumns.remove(columnPosition);
         }
 
-        Collection<Serializable> toRemove = new HashSet<Serializable>();
+        HashSet<Serializable> toRemove = new HashSet<>();
         for (Map.Entry<Serializable, Row<T>> entry : this.selectedRows.entrySet()) {
             entry.getValue().removeItem(columnPosition);
             if (!entry.getValue().hasSelection()) {
@@ -133,10 +138,7 @@ class Selections<T> {
 
     void updateColumnsForRemoval(int columnPosition) {
         // find maximum selected column
-        int maxColumn = 0;
-        for (Integer pos : this.selectedColumns.keySet()) {
-            maxColumn = Math.max(maxColumn, pos);
-        }
+        int maxColumn = this.selectedColumns.keySet().maxIfEmpty(0);
 
         for (int i = columnPosition + 1; i <= maxColumn; i++) {
             Column column = this.selectedColumns.get(i);
@@ -146,8 +148,8 @@ class Selections<T> {
 
                 // also update the row references
                 for (Row<T> row : this.selectedRows.values()) {
-                    Collection<Integer> toRemove = new HashSet<Integer>();
-                    Collection<Integer> toAdd = new HashSet<Integer>();
+                    HashSet<Integer> toRemove = new HashSet<>();
+                    HashSet<Integer> toAdd = new HashSet<>();
                     for (Integer col : row.getItems()) {
                         if (col <= i) {
                             toRemove.add(i);
@@ -163,10 +165,7 @@ class Selections<T> {
 
     void updateColumnsForAddition(int columnPosition) {
         // find maximum selected column
-        int maxColumn = 0;
-        for (Integer pos : this.selectedColumns.keySet()) {
-            maxColumn = Math.max(maxColumn, pos);
-        }
+        int maxColumn = this.selectedColumns.keySet().maxIfEmpty(0);
 
         for (int i = maxColumn; i >= columnPosition; i--) {
             Column column = this.selectedColumns.get(i);
@@ -176,8 +175,8 @@ class Selections<T> {
 
                 // also update the row references
                 for (Row<T> row : this.selectedRows.values()) {
-                    Collection<Integer> toRemove = new HashSet<Integer>();
-                    Collection<Integer> toAdd = new HashSet<Integer>();
+                    HashSet<Integer> toRemove = new HashSet<>();
+                    HashSet<Integer> toAdd = new HashSet<>();
                     for (Integer col : row.getItems()) {
                         if (col >= i) {
                             toRemove.add(i);
@@ -214,10 +213,8 @@ class Selections<T> {
      *
      * @return all columns positions with selected cells
      */
-    List<Integer> getColumnPositions() {
-        List<Integer> keys = new ArrayList<Integer>(this.selectedColumns.keySet());
-        Collections.sort(keys);
-        return keys;
+    int[] getColumnPositions() {
+        return this.selectedColumns.keySet().toSortedArray();
     }
 
     /**
@@ -252,10 +249,10 @@ class Selections<T> {
      * @return all selected cell positions
      */
     Collection<CellPosition<T>> getSelections() {
-        ArrayList<CellPosition<T>> selectedCells = new ArrayList<CellPosition<T>>();
+        ArrayList<CellPosition<T>> selectedCells = new ArrayList<>();
         for (Row<T> row : this.selectedRows.values()) {
-            for (Integer columnPosition : row.getItems()) {
-                CellPosition<T> cell = new CellPosition<T>(row.getRowObject(), columnPosition);
+            for (int columnPosition : row.getItems()) {
+                CellPosition<T> cell = new CellPosition<>(row.getRowObject(), columnPosition);
                 selectedCells.add(cell);
             }
         }
@@ -313,7 +310,7 @@ class Selections<T> {
     private Row<T> retrieveRow(Serializable rowId, T rowObject) {
         Row<T> row = getSelectedColumns(rowId);
         if (row == null) {
-            row = new Row<T>(rowId, rowObject);
+            row = new Row<>(rowId, rowObject);
             this.selectedRows.put(rowId, row);
         }
         return row;
@@ -416,7 +413,7 @@ class Selections<T> {
         /**
          * The selected items
          */
-        private HashSet<S> content = new HashSet<S>();
+        private HashSet<S> content = new HashSet<>();
 
         /**
          * Creates a line with the specified ID
