@@ -1,10 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2012 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- * 
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
+ *
  * Contributors:
  *     Original authors and others - initial API and implementation
  ******************************************************************************/
@@ -23,8 +25,8 @@ public class IsinValueGenerator extends UniqueLongValueGenerator {
 
     @Override
     public Object newValue(Random random) {
-        return prefixes[random.nextInt(prefixes.length)]
-                + format.format(super.newValue(random));
+        return this.prefixes[random.nextInt(this.prefixes.length)]
+                + this.format.format(super.newValue(random));
     }
 
 }
