@@ -1,10 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2012 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- * 
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
+ *
  * Contributors:
  *     Original authors and others - initial API and implementation
  ******************************************************************************/
@@ -17,19 +19,20 @@ import java.util.Random;
 import org.eclipse.nebula.widgets.nattable.dataset.generator.IValueGenerator;
 
 public class ListValueGenerator<T> implements IValueGenerator {
+
     private final List<T> values;
     private final int nullLoadFactor;
 
+    @SafeVarargs
     public ListValueGenerator(int nullLoadFactor, T... values) {
-
         this.nullLoadFactor = nullLoadFactor;
         this.values = Arrays.asList(values);
     }
 
+    @Override
     public Object newValue(Random random) {
-
-        final int choice = random.nextInt(values.size() + nullLoadFactor);
-        return choice >= values.size() ? null : values.get(choice);
+        int choice = random.nextInt(this.values.size() + this.nullLoadFactor);
+        return choice >= this.values.size() ? null : this.values.get(choice);
     }
 
 }
