@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2019 Dirk Fauth.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2019, 2020 Dirk Fauth.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -20,6 +22,7 @@ import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
@@ -256,6 +259,30 @@ public class ComboBoxFilterRowHeaderCompositeIntegrationTest {
         assertEquals(2400, bodyLayer.getFilterList().size());
     }
 
+    @Test
+    public void shouldFilterOnLoadPersistedState() {
+        // load the possible values first to simulate same behavior as in UI,
+        // otherwise exceptions might occur
+        filterRowHeaderLayer.comboBoxDataProvider.getValues(0, 0);
+
+        // filter
+        List<String> firstNames = new ArrayList<>(Arrays.asList("Homer", "Bart"));
+        natTable.doCommand(new UpdateDataCommand(natTable, 1, 2, firstNames));
+        assertEquals(2400, bodyLayer.getFilterList().size());
+
+        // persist
+        Properties properties = new Properties();
+        natTable.saveState("filtered", properties);
+
+        natTable.doCommand(new ClearAllFiltersCommand());
+        // test that nothing is filtered
+        assertEquals(9000, bodyLayer.getFilterList().size());
+
+        // load saved state
+        natTable.loadState("filtered", properties);
+        assertEquals(2400, bodyLayer.getFilterList().size());
+    }
+
     // TODO should not remove filter on sort
     @Ignore
     @Test
@@ -297,7 +324,9 @@ public class ComboBoxFilterRowHeaderCompositeIntegrationTest {
         // edit one entry
         natTable.doCommand(new UpdateDataCommand(natTable, 1, 3, "Bort"));
 
-        countDown.await(2000, TimeUnit.MILLISECONDS);
+        boolean completed = countDown.await(2000, TimeUnit.MILLISECONDS);
+
+        assertTrue("Timeout - no event received", completed);
 
         assertEquals(1, listener.getEventsCount());
 
@@ -323,7 +352,9 @@ public class ComboBoxFilterRowHeaderCompositeIntegrationTest {
 
         natTable.doCommand(new UpdateDataCommand(natTable, 1, 3, "Bart"));
 
-        countDown.await(2000, TimeUnit.MILLISECONDS);
+        completed = countDown.await(2000, TimeUnit.MILLISECONDS);
+
+        assertTrue("Timeout - no event received", completed);
 
         assertEquals(1, listener.getEventsCount());
 
@@ -368,10 +399,12 @@ public class ComboBoxFilterRowHeaderCompositeIntegrationTest {
         bodyLayer.eventList.add(entry);
 
         // long start = System.currentTimeMillis();
-        countDown.await(2000, TimeUnit.MILLISECONDS);
+        boolean completed = countDown.await(2000, TimeUnit.MILLISECONDS);
         // long end = System.currentTimeMillis();
         // System.out.println("duration " + (end - start));
 
+        assertTrue("Timeout - no event received", completed);
+
         assertEquals(2, listener.getEventsCount());
 
         FilterRowComboUpdateEvent evt = listener.getReceivedEvents().get(0);
@@ -406,10 +439,12 @@ public class ComboBoxFilterRowHeaderCompositeIntegrationTest {
         listener.setCountDown(countDown);
 
         // start = System.currentTimeMillis();
-        countDown.await(2000, TimeUnit.MILLISECONDS);
+        completed = countDown.await(2000, TimeUnit.MILLISECONDS);
         // end = System.currentTimeMillis();
         // System.out.println("duration " + (end - start));
 
+        assertTrue("Timeout - no event received", completed);
+
         filterRowHeaderLayer.comboBoxDataProvider.removeCacheUpdateListener(listener);
     }
 
