@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2014, 2017 Dirk Fauth and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2014, 2020 Dirk Fauth and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -277,9 +279,9 @@ public class GroupByDataLayerTest {
                     assertTrue("groupBy column label not found", stack.hasLabel(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column));
 
                     // respect the label order
-                    assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.getLabels().get(0));
-                    assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.getLabels().get(1));
-                    assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.getLabels().get(2));
+                    assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.get(0));
+                    assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.get(1));
+                    assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.get(2));
                 } else {
                     assertFalse("groupBy object label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_OBJECT));
                     assertFalse("groupBy column label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column));
@@ -314,19 +316,19 @@ public class GroupByDataLayerTest {
                         assertTrue("groupBy summary column label not found", stack.hasLabel(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column));
 
                         // respect the label order
-                        assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column, stack.getLabels().get(0));
-                        assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY, stack.getLabels().get(1));
-                        assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.getLabels().get(2));
-                        assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.getLabels().get(3));
-                        assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.getLabels().get(4));
+                        assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column, stack.get(0));
+                        assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY, stack.get(1));
+                        assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.get(2));
+                        assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.get(3));
+                        assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.get(4));
                     } else {
                         assertFalse("groupBy summary label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_SUMMARY));
                         assertFalse("groupBy summary column label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column));
 
                         // respect the label order
-                        assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.getLabels().get(0));
-                        assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.getLabels().get(1));
-                        assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.getLabels().get(2));
+                        assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.get(0));
+                        assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.get(1));
+                        assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.get(2));
                     }
                 } else {
                     assertFalse("groupBy object label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_OBJECT));
@@ -367,28 +369,28 @@ public class GroupByDataLayerTest {
                         // should have conditional formatting
                         if (row == 9) {
                             // respect the label order
-                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column, stack.getLabels().get(0));
-                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY, stack.getLabels().get(1));
-                            assertEquals(MY_LABEL, stack.getLabels().get(2));
-                            assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.getLabels().get(3));
-                            assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.getLabels().get(4));
-                            assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.getLabels().get(5));
+                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column, stack.get(0));
+                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY, stack.get(1));
+                            assertEquals(MY_LABEL, stack.get(2));
+                            assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.get(3));
+                            assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.get(4));
+                            assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.get(5));
                         } else {
                             // respect the label order
-                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column, stack.getLabels().get(0));
-                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY, stack.getLabels().get(1));
-                            assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.getLabels().get(2));
-                            assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.getLabels().get(3));
-                            assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.getLabels().get(4));
+                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column, stack.get(0));
+                            assertEquals(GroupByDataLayer.GROUP_BY_SUMMARY, stack.get(1));
+                            assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.get(2));
+                            assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.get(3));
+                            assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.get(4));
                         }
                     } else {
                         assertFalse("groupBy summary label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_SUMMARY));
                         assertFalse("groupBy summary column label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + column));
 
                         // respect the label order
-                        assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.getLabels().get(0));
-                        assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.getLabels().get(1));
-                        assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.getLabels().get(2));
+                        assertEquals(GroupByDataLayer.GROUP_BY_COLUMN_PREFIX + column, stack.get(0));
+                        assertEquals(GroupByDataLayer.GROUP_BY_OBJECT, stack.get(1));
+                        assertEquals(ColumnLabelAccumulator.COLUMN_LABEL_PREFIX + column, stack.get(2));
                     }
                 } else {
                     assertFalse("groupBy object label found", stack.hasLabel(GroupByDataLayer.GROUP_BY_OBJECT));
@@ -858,6 +860,80 @@ public class GroupByDataLayerTest {
 
     }
 
+    @Test
+    public void testKeepSortOnGrouping() {
+        addSortingCapability();
+
+        // sort by lastname descending
+        this.sortModel.sort(1, SortDirectionEnum.DESC, false);
+
+        // 10 Simpsons, 8 Flanders
+        assertEquals(18, this.dataLayer.getRowCount());
+        for (int i = 0; i < this.dataLayer.getRowCount(); i++) {
+            if (i < 10) {
+                assertEquals("Simpson", this.dataLayer.getDataValue(1, i));
+            } else {
+                assertEquals("Flanders", this.dataLayer.getDataValue(1, i));
+            }
+        }
+
+        // groupby firstname
+        this.groupByModel.addGroupByColumnIndex(0);
+
+        // 10 Simpsons, 8 Flanders, 8 GroupByObjects for firstnames
+        assertEquals(26, this.dataLayer.getRowCount());
+
+        Object o = this.dataLayer.getTreeList().get(0);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Bart", ((GroupByObject) o).getValue());
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 1));
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 2));
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 3));
+
+        o = this.dataLayer.getTreeList().get(4);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Homer", ((GroupByObject) o).getValue());
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 5));
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 6));
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 7));
+
+        o = this.dataLayer.getTreeList().get(8);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Lisa", ((GroupByObject) o).getValue());
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 9));
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 10));
+
+        o = this.dataLayer.getTreeList().get(11);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Marge", ((GroupByObject) o).getValue());
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 12));
+        assertEquals("Simpson", this.dataLayer.getDataValue(1, 13));
+
+        o = this.dataLayer.getTreeList().get(14);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Maude", ((GroupByObject) o).getValue());
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 15));
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 16));
+
+        o = this.dataLayer.getTreeList().get(17);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Ned", ((GroupByObject) o).getValue());
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 18));
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 19));
+
+        o = this.dataLayer.getTreeList().get(20);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Rodd", ((GroupByObject) o).getValue());
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 21));
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 22));
+
+        o = this.dataLayer.getTreeList().get(23);
+        assertTrue("Object is not a GroupByObject", o instanceof GroupByObject);
+        assertEquals("Todd", ((GroupByObject) o).getValue());
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 24));
+        assertEquals("Flanders", this.dataLayer.getDataValue(1, 25));
+    }
+
     @Test
     public void testProvidedLabels() {
         Collection<String> labels = this.dataLayer.getProvidedLabels();
@@ -879,7 +955,6 @@ public class GroupByDataLayerTest {
         assertTrue(labels.contains(GroupByDataLayer.GROUP_BY_SUMMARY_COLUMN_PREFIX + 5));
     }
 
-    @SuppressWarnings("deprecation")
     @Test
     public void testGroupByItemCount() {
         // groupBy lastname
@@ -890,26 +965,19 @@ public class GroupByDataLayerTest {
         GroupByObject simpsons = (GroupByObject) this.dataLayer.getTreeList().get(9);
         assertEquals("Simpson", simpsons.getValue());
 
-        List<Person> elementsInGroup = this.dataLayer.getElementsInGroup(flanders);
         List<Person> itemsInGroup = this.dataLayer.getItemsInGroup(flanders);
         List<Object> rowModelChildren = this.dataLayer.getTreeRowModel().getChildren(0);
-        assertEquals(8, elementsInGroup.size());
         assertEquals(8, itemsInGroup.size());
         assertEquals(8, rowModelChildren.size());
-        assertEquals(elementsInGroup, itemsInGroup);
         assertEquals(itemsInGroup, rowModelChildren);
 
-        elementsInGroup = this.dataLayer.getElementsInGroup(simpsons);
         itemsInGroup = this.dataLayer.getItemsInGroup(simpsons);
         rowModelChildren = this.dataLayer.getTreeRowModel().getChildren(9);
-        assertEquals(10, elementsInGroup.size());
         assertEquals(10, itemsInGroup.size());
         assertEquals(10, rowModelChildren.size());
-        assertEquals(elementsInGroup, itemsInGroup);
         assertEquals(itemsInGroup, rowModelChildren);
     }
 
-    @SuppressWarnings("deprecation")
     @Test
     public void testGroupByItemCountAfterListChange() {
         // groupBy lastname
@@ -920,13 +988,10 @@ public class GroupByDataLayerTest {
         GroupByObject simpsons = (GroupByObject) this.dataLayer.getTreeList().get(9);
         assertEquals("Simpson", simpsons.getValue());
 
-        List<Person> elementsInGroup = this.dataLayer.getElementsInGroup(flanders);
         List<Person> itemsInGroup = this.dataLayer.getItemsInGroup(flanders);
         List<Object> rowModelChildren = this.dataLayer.getTreeRowModel().getChildren(0);
-        assertEquals(8, elementsInGroup.size());
         assertEquals(8, itemsInGroup.size());
         assertEquals(8, rowModelChildren.size());
-        assertEquals(elementsInGroup, itemsInGroup);
         assertEquals(itemsInGroup, rowModelChildren);
 
         this.sortedList.addListEventListener(new ListEventListener<Person>() {
@@ -943,13 +1008,10 @@ public class GroupByDataLayerTest {
 
         this.sortedList.add(p);
 
-        elementsInGroup = this.dataLayer.getElementsInGroup(flanders);
         itemsInGroup = this.dataLayer.getItemsInGroup(flanders);
         rowModelChildren = this.dataLayer.getTreeRowModel().getChildren(0);
-        assertEquals(9, elementsInGroup.size());
         assertEquals(9, itemsInGroup.size());
         assertEquals(9, rowModelChildren.size());
-        assertEquals(elementsInGroup, itemsInGroup);
         assertEquals(itemsInGroup, rowModelChildren);
     }
 
