@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2018 Dirk Fauth.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2018, 2020 Dirk Fauth.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -438,7 +440,9 @@ public class RowStructuralDataChangeLayerIntegrationTest {
 
         // give the GlazedListsEventLayer some time to trigger the
         // RowStructuralRefreshEvent
-        this.lock.await(1000, TimeUnit.MILLISECONDS);
+        boolean completed = this.lock.await(1000, TimeUnit.MILLISECONDS);
+
+        assertTrue("Timeout - no event received", completed);
 
         assertEquals(9, this.filterList.size());
         assertFalse(this.dataChangeLayer.getDataChanges().isEmpty());
@@ -449,7 +453,9 @@ public class RowStructuralDataChangeLayerIntegrationTest {
 
         // give the GlazedListsEventLayer some time to trigger the
         // RowStructuralRefreshEvent
-        this.lock.await(1000, TimeUnit.MILLISECONDS);
+        completed = this.lock.await(1000, TimeUnit.MILLISECONDS);
+
+        assertTrue("Timeout - no event received", completed);
 
         assertEquals(18, this.filterList.size());
         assertFalse(this.dataChangeLayer.getDataChanges().isEmpty());
@@ -478,7 +484,9 @@ public class RowStructuralDataChangeLayerIntegrationTest {
 
         // give the GlazedListsEventLayer some time to trigger the
         // RowStructuralRefreshEvent
-        this.lock.await(1000, TimeUnit.MILLISECONDS);
+        boolean completed = this.lock.await(1000, TimeUnit.MILLISECONDS);
+
+        assertTrue("Timeout - no event received", completed);
 
         assertEquals(18, this.filterList.size());
         assertFalse(this.dataChangeLayer.getDataChanges().isEmpty());
