@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2018 Dirk Fauth and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2013, 2020 Dirk Fauth and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Dirk Fauth <dirk.fauth@googlemail.com> - initial API and implementation
@@ -168,7 +170,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
             boolean useDefaultConfiguration) {
 
         this(filterList,
-                new GlazedListsFilterRowComboBoxDataProvider<T>(
+                new GlazedListsFilterRowComboBoxDataProvider<>(
                         bodyLayer,
                         baseCollection,
                         bodyDataColumnAccessor),
@@ -230,7 +232,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
             boolean useDefaultConfiguration) {
 
         this(filterList,
-                new GlazedListsFilterRowComboBoxDataProvider<T>(
+                new GlazedListsFilterRowComboBoxDataProvider<>(
                         bodyLayer,
                         baseCollection,
                         bodyDataColumnAccessor,
@@ -300,7 +302,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
 
         this(filterList,
                 matcherEditor,
-                new GlazedListsFilterRowComboBoxDataProvider<T>(
+                new GlazedListsFilterRowComboBoxDataProvider<>(
                         bodyLayer,
                         baseCollection,
                         bodyDataColumnAccessor),
@@ -373,7 +375,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
 
         this(filterList,
                 matcherEditor,
-                new GlazedListsFilterRowComboBoxDataProvider<T>(
+                new GlazedListsFilterRowComboBoxDataProvider<>(
                         bodyLayer,
                         baseCollection,
                         bodyDataColumnAccessor,
@@ -470,7 +472,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
             boolean useDefaultConfiguration) {
 
         this(
-                new ComboBoxGlazedListsFilterStrategy<T>(
+                new ComboBoxGlazedListsFilterStrategy<>(
                         comboBoxDataProvider,
                         filterList,
                         bodyDataColumnAccessor,
@@ -534,7 +536,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
             boolean useDefaultConfiguration) {
 
         this(
-                new ComboBoxGlazedListsFilterStrategy<T>(
+                new ComboBoxGlazedListsFilterStrategy<>(
                         comboBoxDataProvider,
                         filterList,
                         matcherEditor,
@@ -594,7 +596,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
         this.comboBoxDataProvider.addCacheUpdateListener(this);
 
         this.filterRowDataLayer =
-                new FilterRowDataLayer<T>(
+                new FilterRowDataLayer<>(
                         this.filterStrategy,
                         columnHeaderLayer,
                         columnHeaderDataProvider,
@@ -750,7 +752,7 @@ public class ComboBoxFilterRowHeaderComposite<T> extends CompositeLayer implemen
         Map<Integer, Object> filterIndexToObjectMap =
                 this.filterRowDataLayer.getFilterRowDataProvider().getFilterIndexToObjectMap();
         Object filterObject = filterIndexToObjectMap.get(event.getColumnIndex());
-        if (filterObject != null && filterObject instanceof Collection) {
+        if (filterObject instanceof Collection) {
             Collection filterCollection = (Collection) filterObject;
             // if a new value was added than ensure it is also added to the
             // filter
