@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2019 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -17,6 +19,7 @@ package org.eclipse.nebula.widgets.nattable.extension.glazedlists.groupBy;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashSet;
 import java.util.List;
@@ -47,12 +50,10 @@ import org.eclipse.nebula.widgets.nattable.sort.ISortModel;
 import org.eclipse.nebula.widgets.nattable.sort.SortDirectionEnum;
 import org.eclipse.nebula.widgets.nattable.style.DisplayMode;
 import org.eclipse.nebula.widgets.nattable.summaryrow.command.CalculateSummaryRowValuesCommand;
-import org.eclipse.nebula.widgets.nattable.tree.ITreeData;
 import org.eclipse.nebula.widgets.nattable.tree.TreeLayer;
 import org.eclipse.nebula.widgets.nattable.util.CalculatedValueCache;
 import org.eclipse.nebula.widgets.nattable.util.ICalculatedValueCache;
 import org.eclipse.nebula.widgets.nattable.util.ICalculatedValueCacheKey;
-import org.eclipse.nebula.widgets.nattable.util.ICalculator;
 import org.eclipse.swt.custom.BusyIndicator;
 import org.eclipse.swt.widgets.Display;
 
@@ -138,10 +139,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      */
     private ICalculatedValueCache valueCache;
 
-    /** Map the group to a dynamic list of group elements */
-    private final Map<GroupByObject, FilterList<T>> filtersByGroup = new ConcurrentHashMap<GroupByObject, FilterList<T>>();
-
-    private final Map<GroupByObject, List<T>> itemsByGroup = new ConcurrentHashMap<GroupByObject, List<T>>();
+    private final Map<GroupByObject, List<T>> itemsByGroup = new ConcurrentHashMap<>();
 
     /**
      * The internal {@link TreeList.ExpansionModel} that is used by default if
@@ -154,13 +152,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      * {@link Matcher} to filter for {@link GroupByObject}s in the
      * {@link TreeList}.
      */
-    private Matcher<Object> groupByMatcher = new Matcher<Object>() {
-
-        @Override
-        public boolean matches(Object item) {
-            return item instanceof GroupByObject;
-        }
-    };
+    private Matcher<Object> groupByMatcher = item -> item instanceof GroupByObject;
 
     /**
      * Create a new {@link GroupByDataLayer} with the given configuration that:
@@ -187,10 +179,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *            this:
      *
      *            <pre>
-     * EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
-     * TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
-     * SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
-     * FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
+     *            EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
+     *            TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
+     *            SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
+     *            FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
      *            </pre>
      *
      *            the <code>FilterList</code> needs to be used as parameter
@@ -230,10 +222,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *            this:
      *
      *            <pre>
-     * EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
-     * TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
-     * SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
-     * FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
+     *            EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
+     *            TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
+     *            SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
+     *            FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
      *            </pre>
      *
      *            the <code>FilterList</code> needs to be used as parameter
@@ -278,10 +270,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *            this:
      *
      *            <pre>
-     * EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
-     * TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
-     * SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
-     * FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
+     *            EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
+     *            TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
+     *            SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
+     *            FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
      *            </pre>
      *
      *            the <code>FilterList</code> needs to be used as parameter
@@ -324,10 +316,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *            this:
      *
      *            <pre>
-     * EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
-     * TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
-     * SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
-     * FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
+     *            EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
+     *            TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
+     *            SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
+     *            FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
      *            </pre>
      *
      *            the <code>FilterList</code> needs to be used as parameter
@@ -373,10 +365,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *            this:
      *
      *            <pre>
-     * EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
-     * TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
-     * SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
-     * FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
+     *            EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
+     *            TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
+     *            SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
+     *            FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
      *            </pre>
      *
      *            the <code>FilterList</code> needs to be used as parameter
@@ -424,10 +416,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *            this:
      *
      *            <pre>
-     * EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
-     * TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
-     * SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
-     * FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
+     *            EventList&lt;T&gt; eventList = GlazedLists.eventList(values);
+     *            TransformedList&lt;T, T&gt; rowObjectsGlazedList = GlazedLists.threadSafeList(eventList);
+     *            SortedList&lt;T&gt; sortedList = new SortedList&lt;&gt;(rowObjectsGlazedList, null);
+     *            FilterList&lt;T&gt; filterList = new FilterList&lt;&gt;(sortedList);
      *            </pre>
      *
      *            the <code>FilterList</code> needs to be used as parameter
@@ -471,7 +463,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
         this.groupByColumnAccessor = new GroupByColumnAccessor(columnAccessor);
 
         this.treeFormat = createGroupByTreeFormat(groupByModel, (IColumnAccessor<T>) this.groupByColumnAccessor);
-        this.treeFormat.setComparator(new GroupByComparator<T>(groupByModel, columnAccessor, this));
+        this.treeFormat.setComparator(new GroupByComparator<>(groupByModel, columnAccessor, this));
 
         if (expansionModel == null) {
             this.groupByExpansionModel = new GroupByExpansionModel();
@@ -480,8 +472,8 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
             this.treeList = new TreeList(eventList, this.treeFormat, expansionModel);
         }
 
-        this.treeData = new GlazedListTreeData<Object>(this.treeList);
-        this.treeRowModel = new GlazedListTreeRowModel<Object>(this.treeData);
+        this.treeData = new GlazedListTreeData<>(this.treeList);
+        this.treeRowModel = new GlazedListTreeRowModel<>(this.treeData);
 
         this.configRegistry = configRegistry;
 
@@ -507,21 +499,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      *         structure.
      */
     protected GroupByTreeFormat<T> createGroupByTreeFormat(GroupByModel groupByModel, IColumnAccessor<T> groupByColumnAccessor) {
-        return new GroupByTreeFormat<T>(groupByModel, groupByColumnAccessor);
-    }
-
-    /**
-     * @param model
-     *            The {@link ISortModel} that should be set to the
-     *            {@link IGroupByComparator} that is necessary to create the
-     *            sorted tree structure.
-     * @see IGroupByComparator#setSortModel(ISortModel)
-     * @deprecated use
-     *             {@link #initializeTreeComparator(ISortModel, IUniqueIndexLayer, boolean)}
-     */
-    @Deprecated
-    public void setSortModel(ISortModel model) {
-        this.treeFormat.setSortModel(model);
+        return new GroupByTreeFormat<>(groupByModel, groupByColumnAccessor);
     }
 
     /**
@@ -602,36 +580,30 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
         // Perform the update showing the busy indicator, as creating the
         // groupby structure costs time. This is related to dynamically building
         // a tree structure with additional objects
-        BusyIndicator.showWhile(Display.getDefault(), new Runnable() {
+        BusyIndicator.showWhile(Display.getDefault(), () -> {
+            GroupByDataLayer.this.eventList.getReadWriteLock().writeLock().lock();
+            try {
+                /*
+                 * The workaround for the update issue suggested on the mailing
+                 * list iterates over the whole list. This causes a lot of list
+                 * change events, which also cost processing time. Instead we
+                 * are performing a clear()-addAll() which is slightly faster.
+                 */
+                EventList<T> temp = GlazedLists.eventList(GroupByDataLayer.this.eventList);
+                GroupByDataLayer.this.eventList.clear();
+                GroupByDataLayer.this.eventList.addAll(temp);
 
-            @Override
-            public void run() {
-                GroupByDataLayer.this.eventList.getReadWriteLock().writeLock().lock();
-                try {
-                    /*
-                     * The workaround for the update issue suggested on the
-                     * mailing list iterates over the whole list. This causes a
-                     * lot of list change events, which also cost processing
-                     * time. Instead we are performing a clear()-addAll() which
-                     * is slightly faster.
-                     */
-                    EventList<T> temp = GlazedLists.eventList(GroupByDataLayer.this.eventList);
-                    GroupByDataLayer.this.eventList.clear();
-                    GroupByDataLayer.this.eventList.addAll(temp);
-
-                    /*
-                     * Collect the created GroupByObjects and cleanup local
-                     * caches
-                     */
-                    if (GroupByDataLayer.this.groupByExpansionModel != null) {
-                        FilterList<Object> groupByObjects = new FilterList<Object>(
-                                GroupByDataLayer.this.treeList,
-                                GroupByDataLayer.this.groupByMatcher);
-                        GroupByDataLayer.this.groupByExpansionModel.cleanupCollapsed(groupByObjects);
-                    }
-                } finally {
-                    GroupByDataLayer.this.eventList.getReadWriteLock().writeLock().unlock();
+                /*
+                 * Collect the created GroupByObjects and cleanup local caches
+                 */
+                if (GroupByDataLayer.this.groupByExpansionModel != null) {
+                    FilterList<Object> groupByObjects = new FilterList<>(
+                            GroupByDataLayer.this.treeList,
+                            GroupByDataLayer.this.groupByMatcher);
+                    GroupByDataLayer.this.groupByExpansionModel.cleanupCollapsed(groupByObjects);
                 }
+            } finally {
+                GroupByDataLayer.this.eventList.getReadWriteLock().writeLock().unlock();
             }
         });
     }
@@ -643,11 +615,10 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
         // applied sorting although showing the sort indicator)
         // for better user experience we remember the sort state and reapply it
         // after the tree update
-        List<Integer> sortedIndexes = null;
-        List<SortDirectionEnum> sortDirections = null;
+        List<Integer> sortedIndexes = Collections.emptyList();
+        List<SortDirectionEnum> sortDirections = new ArrayList<>();
         if (this.treeFormat.getSortModel() != null) {
             sortedIndexes = this.treeFormat.getSortModel().getSortedColumnIndexes();
-            sortDirections = new ArrayList<SortDirectionEnum>();
             for (Integer index : sortedIndexes) {
                 sortDirections.add(this.treeFormat.getSortModel().getSortDirection(index));
             }
@@ -762,12 +733,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
                         rowPosition,
                         new GroupByValueCacheKey(columnPosition, rowPosition, groupByObject),
                         calculateInBackground,
-                        new ICalculator() {
-                            @Override
-                            public Object executeCalculation() {
-                                return summaryProvider.summarize(columnPosition, children);
-                            }
-                        });
+                        () -> summaryProvider.summarize(columnPosition, children));
             }
         }
         return super.getDataValueByPosition(columnPosition, rowPosition);
@@ -779,7 +745,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
             return this.configRegistry.getConfigAttribute(
                     GroupByConfigAttributes.GROUP_BY_SUMMARY_PROVIDER,
                     DisplayMode.NORMAL,
-                    labelStack.getLabels());
+                    labelStack);
         }
 
         return null;
@@ -846,12 +812,12 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
                             GroupByObject groupByObject = (GroupByObject) this.treeData.getDataAtIndex(i);
                             final List<T> children = getItemsInGroup(groupByObject);
                             final int col = j;
-                            this.valueCache.getCalculatedValue(j, i, new GroupByValueCacheKey(j, i, groupByObject), false, new ICalculator() {
-                                @Override
-                                public Object executeCalculation() {
-                                    return summaryProvider.summarize(col, children);
-                                }
-                            });
+                            this.valueCache.getCalculatedValue(
+                                    j,
+                                    i,
+                                    new GroupByValueCacheKey(j, i, groupByObject),
+                                    false,
+                                    () -> summaryProvider.summarize(col, children));
                         }
                     }
                 }
@@ -913,7 +879,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
     private class GroupByExpansionModel implements TreeList.ExpansionModel<Object> {
 
         // remember collapsed states because of update workaround
-        Set<Object> collapsed = new HashSet<Object>();
+        Set<Object> collapsed = new HashSet<>();
 
         /**
          * Determine the specified element's initial expand/collapse state.
@@ -949,37 +915,6 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
         }
     }
 
-    /**
-     * Get the list of the items in a group. Used for example to calculate the
-     * group summary values or group item count.
-     * <p>
-     * It returns the same as {@link ITreeData#getChildren(Object, boolean)},
-     * e.g. <code>treeData.getChildren(groupDescriptor, true)</code>, but in a
-     * more efficient way.
-     * </p>
-     * <p>
-     * Note: This method returns a filtered view on the base list. Therefore it
-     * is not thread-safe as it could lead to concurrent modification exceptions
-     * if the underlying list changes while the FilterList is processed.
-     * </p>
-     *
-     * @param group
-     *            The {@link GroupByObject} for which the children should be
-     *            retrieved.
-     * @return The {@link FilterList} of elements
-     *
-     * @deprecated Use {@link #getItemsInGroup(GroupByObject)}
-     */
-    @Deprecated
-    public FilterList<T> getElementsInGroup(GroupByObject group) {
-        FilterList<T> elementsInGroup = this.filtersByGroup.get(group);
-        if (elementsInGroup == null) {
-            elementsInGroup = new FilterList<T>(this.eventList, getGroupDescriptorMatcher(group, this.columnAccessor));
-            this.filtersByGroup.put(group, elementsInGroup);
-        }
-        return elementsInGroup;
-    }
-
     /**
      * Get the list of the items in a group. Used for example to calculate the
      * group summary values or group item count.
@@ -996,18 +931,16 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      * @since 1.5
      */
     public List<T> getItemsInGroup(GroupByObject group) {
-        List<T> elementsInGroup = this.itemsByGroup.get(group);
-        if (elementsInGroup == null) {
+        return this.itemsByGroup.computeIfAbsent(group, g -> {
+
             this.eventList.getReadWriteLock().readLock().lock();
             try {
-                FilterList<T> filterList = new FilterList<T>(this.eventList, getGroupDescriptorMatcher(group, this.columnAccessor));
-                elementsInGroup = new ArrayList<T>(filterList);
-                this.itemsByGroup.put(group, elementsInGroup);
+                FilterList<T> filterList = new FilterList<>(this.eventList, getGroupDescriptorMatcher(g, this.columnAccessor));
+                return new ArrayList<>(filterList);
             } finally {
                 this.eventList.getReadWriteLock().readLock().unlock();
             }
-        }
-        return elementsInGroup;
+        });
     }
 
     /**
@@ -1024,7 +957,7 @@ public class GroupByDataLayer<T> extends DataLayer implements Observer {
      * @see GroupDescriptorMatcher
      */
     protected Matcher<T> getGroupDescriptorMatcher(GroupByObject group, IColumnAccessor<T> columnAccessor) {
-        return new GroupDescriptorMatcher<T>(group, columnAccessor);
+        return new GroupDescriptorMatcher<>(group, columnAccessor);
     }
 
     /**
