@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 Original authors and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2012, 2020 Original authors and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Original authors and others - initial API and implementation
@@ -23,17 +25,19 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.apache.poi.ss.usermodel.BorderStyle;
 import org.apache.poi.ss.usermodel.Cell;
 import org.apache.poi.ss.usermodel.CellStyle;
 import org.apache.poi.ss.usermodel.ClientAnchor;
 import org.apache.poi.ss.usermodel.CreationHelper;
 import org.apache.poi.ss.usermodel.Drawing;
+import org.apache.poi.ss.usermodel.FillPatternType;
 import org.apache.poi.ss.usermodel.Font;
+import org.apache.poi.ss.usermodel.HorizontalAlignment;
 import org.apache.poi.ss.usermodel.Picture;
 import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
+import org.apache.poi.ss.usermodel.VerticalAlignment;
 import org.apache.poi.ss.usermodel.Workbook;
 import org.apache.poi.ss.util.CellRangeAddress;
 import org.apache.poi.util.IOUtils;
@@ -58,10 +62,12 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.widgets.Shell;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public abstract class PoiExcelExporter implements ILayerExporter {
 
-    private static final Log LOG = LogFactory.getLog(PoiExcelExporter.class);
+    private static final Logger LOG = LoggerFactory.getLogger(PoiExcelExporter.class);
 
     private final IOutputStreamProvider outputStreamProvider;
 
@@ -85,12 +91,12 @@ public abstract class PoiExcelExporter implements ILayerExporter {
     protected NumberFormat nf = NumberFormat.getInstance();
 
     protected CreationHelper helper;
-    protected Drawing drawing;
+    protected Drawing<?> drawing;
 
     protected boolean exportOnSameSheet = false;
     protected int currentRow = 0;
 
-    private Set<Integer> hiddenColumnPositions = new HashSet<Integer>();
+    private Set<Integer> hiddenColumnPositions = new HashSet<>();
 
     public PoiExcelExporter(IOutputStreamProvider outputStreamProvider) {
         this.outputStreamProvider = outputStreamProvider;
@@ -103,7 +109,7 @@ public abstract class PoiExcelExporter implements ILayerExporter {
 
     @Override
     public void exportBegin(OutputStream outputStream) throws IOException {
-        this.xlCellStyles = new HashMap<ExcelCellStyleAttributes, CellStyle>();
+        this.xlCellStyles = new HashMap<>();
         this.xlWorkbook = createWorkbook();
         // the hidden column positions are determined by inspection so
         // it needs to be cleared at the beginning
@@ -137,7 +143,8 @@ public abstract class PoiExcelExporter implements ILayerExporter {
     }
 
     @Override
-    public void exportLayerEnd(OutputStream outputStream, String layerName) throws IOException {}
+    public void exportLayerEnd(OutputStream outputStream, String layerName) throws IOException {
+    }
 
     @Override
     public void exportRowBegin(OutputStream outputStream, int rowPosition) throws IOException {
@@ -153,7 +160,8 @@ public abstract class PoiExcelExporter implements ILayerExporter {
     }
 
     @Override
-    public void exportRowEnd(OutputStream outputStream, int rowPosition) throws IOException {}
+    public void exportRowEnd(OutputStream outputStream, int rowPosition) throws IOException {
+    }
 
     @Override
     public void exportCell(
@@ -199,7 +207,7 @@ public abstract class PoiExcelExporter implements ILayerExporter {
         CellStyleProxy cellStyle = new CellStyleProxy(
                 configRegistry,
                 DisplayMode.NORMAL,
-                cell.getConfigLabels().getLabels());
+                cell.getConfigLabels());
         Color fg = cellStyle.getAttributeValue(CellStyleAttributes.FOREGROUND_COLOR);
         Color bg = cellStyle.getAttributeValue(CellStyleAttributes.BACKGROUND_COLOR);
         org.eclipse.swt.graphics.Font font = cellStyle.getAttributeValue(CellStyleAttributes.FONT);
@@ -216,9 +224,9 @@ public abstract class PoiExcelExporter implements ILayerExporter {
         ICellPainter cellPainter = configRegistry.getConfigAttribute(
                 CellConfigAttributes.CELL_PAINTER,
                 DisplayMode.NORMAL,
-                cell.getConfigLabels().getLabels());
-        boolean vertical = this.applyVerticalTextConfiguration ? isVertical(cellPainter) : false;
-        boolean wrap = this.applyTextWrapping ? wrapText(cellPainter) : false;
+                cell.getConfigLabels());
+        boolean vertical = this.applyVerticalTextConfiguration && isVertical(cellPainter);
+        boolean wrap = this.applyTextWrapping && wrapText(cellPainter);
 
         CellStyle xlCellStyle = getExcelCellStyle(fg, bg, fontData, dataFormat, hAlign, vAlign, vertical, wrap, this.applyCellBorders);
         xlCell.setCellStyle(xlCellStyle);
@@ -337,7 +345,7 @@ public abstract class PoiExcelExporter implements ILayerExporter {
             if (this.applyBackgroundColor) {
                 // Note: xl fill foreground = background
                 setFillForegroundColor(xlCellStyle, bg);
-                xlCellStyle.setFillPattern(CellStyle.SOLID_FOREGROUND);
+                xlCellStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);
             }
 
             Font xlFont = this.xlWorkbook.createFont();
@@ -353,32 +361,32 @@ public abstract class PoiExcelExporter implements ILayerExporter {
                 xlCellStyle.setWrapText(wrap);
 
             if (border) {
-                xlCellStyle.setBorderTop(CellStyle.BORDER_THIN);
-                xlCellStyle.setBorderRight(CellStyle.BORDER_THIN);
-                xlCellStyle.setBorderBottom(CellStyle.BORDER_THIN);
-                xlCellStyle.setBorderLeft(CellStyle.BORDER_THIN);
+                xlCellStyle.setBorderTop(BorderStyle.THIN);
+                xlCellStyle.setBorderRight(BorderStyle.THIN);
+                xlCellStyle.setBorderBottom(BorderStyle.THIN);
+                xlCellStyle.setBorderLeft(BorderStyle.THIN);
             }
 
             switch (hAlign) {
                 case SWT.CENTER:
-                    xlCellStyle.setAlignment(CellStyle.ALIGN_CENTER);
+                    xlCellStyle.setAlignment(HorizontalAlignment.CENTER);
                     break;
                 case SWT.LEFT:
-                    xlCellStyle.setAlignment(CellStyle.ALIGN_LEFT);
+                    xlCellStyle.setAlignment(HorizontalAlignment.LEFT);
                     break;
                 case SWT.RIGHT:
-                    xlCellStyle.setAlignment(CellStyle.ALIGN_RIGHT);
+                    xlCellStyle.setAlignment(HorizontalAlignment.RIGHT);
                     break;
             }
             switch (vAlign) {
                 case SWT.TOP:
-                    xlCellStyle.setVerticalAlignment(CellStyle.VERTICAL_TOP);
+                    xlCellStyle.setVerticalAlignment(VerticalAlignment.TOP);
                     break;
                 case SWT.CENTER:
-                    xlCellStyle.setVerticalAlignment(CellStyle.VERTICAL_CENTER);
+                    xlCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
                     break;
                 case SWT.BOTTOM:
-                    xlCellStyle.setVerticalAlignment(CellStyle.VERTICAL_BOTTOM);
+                    xlCellStyle.setVerticalAlignment(VerticalAlignment.BOTTOM);
                     break;
             }
 
@@ -406,7 +414,7 @@ public abstract class PoiExcelExporter implements ILayerExporter {
         String dataFormat = configRegistry.getConfigAttribute(
                 ExportConfigAttributes.DATE_FORMAT,
                 DisplayMode.NORMAL,
-                cell.getConfigLabels().getLabels());
+                cell.getConfigLabels());
         if (dataFormat == null) {
             dataFormat = "m/d/yy h:mm"; //$NON-NLS-1$
         }
@@ -641,6 +649,7 @@ public abstract class PoiExcelExporter implements ILayerExporter {
      *
      * @since 1.5
      */
+    @Override
     public void setExportOnSameSheet(boolean sameSheet) {
         this.exportOnSameSheet = sameSheet;
     }
